/*
 * Copyright (c) 2012-2013, The Linux Foundation. All rights reserved.
 *
 * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
 *
 *
 * Permission to use, copy, modify, and/or distribute this software for
 * any purpose with or without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
 * WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL
 * DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
 * PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */
/*
 * Copyright (c) 2012, The Linux Foundation. All rights reserved.
 *
 * Previously licensed under the ISC license by Qualcomm Atheros, Inc.
 *
 *
 * Permission to use, copy, modify, and/or distribute this software for
 * any purpose with or without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
 * WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL
 * DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
 * PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */

/*
 * Copyright (C) 2007-2009 QUALCOMM Incorporated. All rights reserved. Proprietary and Confidential.
 */

/*
 * DO NOT EDIT - This file is generated automatically
 */

/*
 * IMPORTANT:  This file is for system that supports both STA and AP mode.
 */


#ifndef __WNICFGAP_H
#define __WNICFGAP_H

/*
 * Configuration Parameter ID for STA and AP
 */

#define WNI_CFG_STA_ID    0
#define WNI_CFG_CF_POLLABLE    1
#define WNI_CFG_CFP_PERIOD    2
#define WNI_CFG_CFP_MAX_DURATION    3
#define WNI_CFG_SSID    4
#define WNI_CFG_BEACON_INTERVAL    5
#define WNI_CFG_DTIM_PERIOD    6
#define WNI_CFG_WEP_KEY_LENGTH    7
#define WNI_CFG_WEP_DEFAULT_KEY_TABLE    8
#define WNI_CFG_WEP_DEFAULT_KEY_TABLE_ROW    4
#define WNI_CFG_WEP_DEFAULT_KEY_TABLE_COL    1
#define WNI_CFG_WEP_DEFAULT_KEY_1    8
#define WNI_CFG_WEP_DEFAULT_KEY_2    9
#define WNI_CFG_WEP_DEFAULT_KEY_3    10
#define WNI_CFG_WEP_DEFAULT_KEY_4    11
#define WNI_CFG_WEP_DEFAULT_KEYID    12
#define WNI_CFG_EXCLUDE_UNENCRYPTED    13
#define WNI_CFG_RTS_THRESHOLD    14
#define WNI_CFG_SHORT_RETRY_LIMIT    15
#define WNI_CFG_LONG_RETRY_LIMIT    16
#define WNI_CFG_FRAGMENTATION_THRESHOLD    17
#define WNI_CFG_ACTIVE_MINIMUM_CHANNEL_TIME    18
#define WNI_CFG_ACTIVE_MAXIMUM_CHANNEL_TIME    19
#define WNI_CFG_PASSIVE_MINIMUM_CHANNEL_TIME    20
#define WNI_CFG_PASSIVE_MAXIMUM_CHANNEL_TIME    21
#define WNI_CFG_JOIN_FAILURE_TIMEOUT    22
#define WNI_CFG_AUTHENTICATE_FAILURE_TIMEOUT    23
#define WNI_CFG_AUTHENTICATE_RSP_TIMEOUT    24
#define WNI_CFG_ASSOCIATION_FAILURE_TIMEOUT    25
#define WNI_CFG_REASSOCIATION_FAILURE_TIMEOUT    26
#define WNI_CFG_RA_PERIODICITY_TIMEOUT_IN_PS    27
#define WNI_CFG_PS_ENABLE_BCN_FILTER    28
#define WNI_CFG_PS_ENABLE_HEART_BEAT    29
#define WNI_CFG_PS_ENABLE_RSSI_MONITOR    30
#define WNI_CFG_PS_DATA_INACTIVITY_TIMEOUT    31
#define WNI_CFG_RF_SETTLING_TIME_CLK    32
#define WNI_CFG_SUPPORTED_RATES_11B    33
#define WNI_CFG_SUPPORTED_RATES_11A    34
#define WNI_CFG_PHY_MODE    35
#define WNI_CFG_DOT11_MODE    36
#define WNI_CFG_OPERATIONAL_RATE_SET    37
#define WNI_CFG_EXTENDED_OPERATIONAL_RATE_SET    38
#define WNI_CFG_PROPRIETARY_OPERATIONAL_RATE_SET    39
#define WNI_CFG_BSSID    40
#define WNI_CFG_LISTEN_INTERVAL    41
#define WNI_CFG_VALID_CHANNEL_LIST    42
#define WNI_CFG_CURRENT_CHANNEL    43
#define WNI_CFG_DEFAULT_RATE_INDEX_5GHZ    44
#define WNI_CFG_DEFAULT_RATE_INDEX_24GHZ    45
#define WNI_CFG_RATE_ADAPTATION_TYPE    46
#define WNI_CFG_FIXED_RATE    47
#define WNI_CFG_FIXED_RATE_MULTICAST_24GHZ    48
#define WNI_CFG_FIXED_RATE_MULTICAST_5GHZ    49
#define WNI_CFG_RETRYRATE_POLICY    50
#define WNI_CFG_RETRYRATE_SECONDARY    51
#define WNI_CFG_RETRYRATE_TERTIARY    52
#define WNI_CFG_APSD_ENABLED    53
#define WNI_CFG_SHARED_KEY_AUTH_ENABLE    54
#define WNI_CFG_OPEN_SYSTEM_AUTH_ENABLE    55
#define WNI_CFG_AUTHENTICATION_TYPE    56
#define WNI_CFG_CF_POLL_REQUEST    57
#define WNI_CFG_PRIVACY_ENABLED    58
#define WNI_CFG_SHORT_PREAMBLE    59
#define WNI_CFG_SHORT_SLOT_TIME    60
#define WNI_CFG_ACCEPT_SHORT_SLOT_ASSOC_ONLY    61
#define WNI_CFG_QOS_ENABLED    62
#define WNI_CFG_HCF_ENABLED    63
#define WNI_CFG_RSN_ENABLED    64
#define WNI_CFG_BACKGROUND_SCAN_PERIOD    65
#define WNI_CFG_MAX_NUM_PRE_AUTH    66
#define WNI_CFG_PREAUTH_CLNUP_TIMEOUT    67
#define WNI_CFG_RELEASE_AID_TIMEOUT    68
#define WNI_CFG_HEART_BEAT_THRESHOLD    69
#define WNI_CFG_PROBE_AFTER_HB_FAIL_TIMEOUT    70
#define WNI_CFG_MANUFACTURER_OUI    71
#define WNI_CFG_MANUFACTURER_NAME    72
#define WNI_CFG_MODEL_NUMBER    73
#define WNI_CFG_MODEL_NAME    74
#define WNI_CFG_MANUFACTURER_PRODUCT_NAME    75
#define WNI_CFG_MANUFACTURER_PRODUCT_VERSION    76
#define WNI_CFG_11D_ENABLED    77
#define WNI_CFG_MAX_TX_POWER_2_4    78
#define WNI_CFG_MAX_TX_POWER_5    79
#define WNI_CFG_NETWORK_DENSITY    80
#define WNI_CFG_ADAPTIVE_THRESHOLD_ALGORITHM    81
#define WNI_CFG_CURRENT_TX_ANTENNA    82
#define WNI_CFG_CURRENT_RX_ANTENNA    83
#define WNI_CFG_CURRENT_TX_POWER_LEVEL    84
#define WNI_CFG_POWER_STATE_PER_CHAIN    85
#define WNI_CFG_NEW_BSS_FOUND_IND    86
#define WNI_CFG_PROPRIETARY_ANI_FEATURES_ENABLED    87
#define WNI_CFG_PROPRIETARY_RATES_ENABLED    88
#define WNI_CFG_AP_NODE_NAME    89
#define WNI_CFG_COUNTRY_CODE    90
#define WNI_CFG_11H_ENABLED    91
#define WNI_CFG_WT_CNF_TIMEOUT    92
#define WNI_CFG_KEEPALIVE_TIMEOUT    93
#define WNI_CFG_PROXIMITY    94
#define WNI_CFG_LOG_LEVEL    95
#define WNI_CFG_OLBC_DETECT_TIMEOUT    96
#define WNI_CFG_PROTECTION_ENABLED    97
#define WNI_CFG_11G_PROTECTION_ALWAYS    98
#define WNI_CFG_FORCE_POLICY_PROTECTION    99
#define WNI_CFG_11G_SHORT_PREAMBLE_ENABLED    100
#define WNI_CFG_11G_SHORT_SLOT_TIME_ENABLED    101
#define WNI_CFG_CAL_PERIOD    102
#define WNI_CFG_STATS_PERIOD    103
#define WNI_CFG_CAL_CONTROL    104
#define WNI_CFG_11G_ONLY_POLICY    105
#define WNI_CFG_PACKET_CLASSIFICATION    106
#define WNI_CFG_WME_ENABLED    107
#define WNI_CFG_ADDTS_RSP_TIMEOUT    108
#define WNI_CFG_MAX_SP_LENGTH    109
#define WNI_CFG_KEEP_ALIVE_STA_LIMIT_THRESHOLD    110
#define WNI_CFG_SEND_SINGLE_SSID_ALWAYS    111
#define WNI_CFG_WSM_ENABLED    112
#define WNI_CFG_PROP_CAPABILITY    113
#define WNI_CFG_EDCA_PROFILE    114
#define WNI_CFG_EDCA_ANI_ACBK_LOCAL    115
#define WNI_CFG_EDCA_ANI_ACBE_LOCAL    116
#define WNI_CFG_EDCA_ANI_ACVI_LOCAL    117
#define WNI_CFG_EDCA_ANI_ACVO_LOCAL    118
#define WNI_CFG_EDCA_ANI_ACBK    119
#define WNI_CFG_EDCA_ANI_ACBE    120
#define WNI_CFG_EDCA_ANI_ACVI    121
#define WNI_CFG_EDCA_ANI_ACVO    122
#define WNI_CFG_EDCA_WME_ACBK_LOCAL    123
#define WNI_CFG_EDCA_WME_ACBE_LOCAL    124
#define WNI_CFG_EDCA_WME_ACVI_LOCAL    125
#define WNI_CFG_EDCA_WME_ACVO_LOCAL    126
#define WNI_CFG_EDCA_WME_ACBK    127
#define WNI_CFG_EDCA_WME_ACBE    128
#define WNI_CFG_EDCA_WME_ACVI    129
#define WNI_CFG_EDCA_WME_ACVO    130
#define WNI_CFG_EDCA_TIT_DEMO_ACBK_LOCAL    131
#define WNI_CFG_EDCA_TIT_DEMO_ACBE_LOCAL    132
#define WNI_CFG_EDCA_TIT_DEMO_ACVI_LOCAL    133
#define WNI_CFG_EDCA_TIT_DEMO_ACVO_LOCAL    134
#define WNI_CFG_EDCA_TIT_DEMO_ACBK    135
#define WNI_CFG_EDCA_TIT_DEMO_ACBE    136
#define WNI_CFG_EDCA_TIT_DEMO_ACVI    137
#define WNI_CFG_EDCA_TIT_DEMO_ACVO    138
#define WNI_CFG_RDET_FLAG    139
#define WNI_CFG_RADAR_CHANNEL_LIST    140
#define WNI_CFG_LOCAL_POWER_CONSTRAINT    141
#define WNI_CFG_ADMIT_POLICY    142
#define WNI_CFG_ADMIT_BWFACTOR    143
#define WNI_CFG_MAX_CONSECUTIVE_BACKGROUND_SCAN_FAILURE    144
#define WNI_CFG_CHANNEL_BONDING_MODE    145
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE    146
#define WNI_CFG_DYNAMIC_THRESHOLD_ZERO    147
#define WNI_CFG_DYNAMIC_THRESHOLD_ONE    148
#define WNI_CFG_DYNAMIC_THRESHOLD_TWO    149
#define WNI_CFG_TRIG_STA_BK_SCAN    150
#define WNI_CFG_DYNAMIC_PROFILE_SWITCHING    151
#define WNI_CFG_SCAN_CONTROL_LIST    152
#define WNI_CFG_MIMO_ENABLED    153
#define WNI_CFG_BLOCK_ACK_ENABLED    154
#define WNI_CFG_BA_ACTIVITY_CHECK_TIMEOUT    155
#define WNI_CFG_HT_RX_STBC    156
#define WNI_CFG_HT_CAP_INFO    157
#define WNI_CFG_HT_AMPDU_PARAMS    158
#define WNI_CFG_SUPPORTED_MCS_SET    159
#define WNI_CFG_EXT_HT_CAP_INFO    160
#define WNI_CFG_TX_BF_CAP    161
#define WNI_CFG_AS_CAP    162
#define WNI_CFG_HT_INFO_FIELD1    163
#define WNI_CFG_HT_INFO_FIELD2    164
#define WNI_CFG_HT_INFO_FIELD3    165
#define WNI_CFG_BASIC_MCS_SET    166
#define WNI_CFG_CURRENT_MCS_SET    167
#define WNI_CFG_GREENFIELD_CAPABILITY    168
#define WNI_CFG_VHT_MAX_MPDU_LENGTH    169
#define WNI_CFG_VHT_SUPPORTED_CHAN_WIDTH_SET    170
#define WNI_CFG_VHT_LDPC_CODING_CAP    171
#define WNI_CFG_VHT_SHORT_GI_80MHZ    172
#define WNI_CFG_VHT_SHORT_GI_160_AND_80_PLUS_80MHZ    173
#define WNI_CFG_VHT_TXSTBC    174
#define WNI_CFG_VHT_RXSTBC    175
#define WNI_CFG_VHT_SU_BEAMFORMER_CAP    176
#define WNI_CFG_VHT_SU_BEAMFORMEE_CAP    177
#define WNI_CFG_VHT_CSN_BEAMFORMEE_ANT_SUPPORTED    178
#define WNI_CFG_VHT_NUM_SOUNDING_DIMENSIONS    179
#define WNI_CFG_VHT_MU_BEAMFORMER_CAP    180
#define WNI_CFG_VHT_MU_BEAMFORMEE_CAP    181
#define WNI_CFG_VHT_TXOP_PS    182
#define WNI_CFG_VHT_HTC_VHTC_CAP    183
#define WNI_CFG_VHT_AMPDU_LEN_EXPONENT    184
#define WNI_CFG_VHT_LINK_ADAPTATION_CAP    185
#define WNI_CFG_VHT_RX_ANT_PATTERN    186
#define WNI_CFG_VHT_TX_ANT_PATTERN    187
#define WNI_CFG_VHT_RX_MCS_MAP    188
#define WNI_CFG_VHT_TX_MCS_MAP    189
#define WNI_CFG_VHT_RX_HIGHEST_SUPPORTED_DATA_RATE    190
#define WNI_CFG_VHT_TX_HIGHEST_SUPPORTED_DATA_RATE    191
#define WNI_CFG_VHT_CHANNEL_WIDTH    192
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT1    193
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT2    194
#define WNI_CFG_VHT_BASIC_MCS_SET    195
#define WNI_CFG_VHT_MU_MIMO_CAP_STA_COUNT    196
#define WNI_CFG_VHT_SS_UNDER_UTIL    197
#define WNI_CFG_VHT_40MHZ_UTILIZATION    198
#define WNI_CFG_VHT_80MHZ_UTILIZATION    199
#define WNI_CFG_VHT_160MHZ_UTILIZATION    200
#define WNI_CFG_MAX_AMSDU_LENGTH    201
#define WNI_CFG_MPDU_DENSITY    202
#define WNI_CFG_NUM_BUFF_ADVERT    203
#define WNI_CFG_MAX_RX_AMPDU_FACTOR    204
#define WNI_CFG_SHORT_GI_20MHZ    205
#define WNI_CFG_SHORT_GI_40MHZ    206
#define WNI_CFG_RIFS_ENABLED    207
#define WNI_CFG_MAX_PS_POLL    208
#define WNI_CFG_NUM_BEACON_PER_RSSI_AVERAGE    209
#define WNI_CFG_RSSI_FILTER_PERIOD    210
#define WNI_CFG_MIN_RSSI_THRESHOLD    211
#define WNI_CFG_NTH_BEACON_FILTER    212
#define WNI_CFG_BROADCAST_FRAME_FILTER_ENABLE    213
#define WNI_CFG_SCAN_IN_POWERSAVE    214
#define WNI_CFG_IGNORE_DTIM    215
#define WNI_CFG_WOWLAN_UCAST_PATTERN_FILTER_ENABLE    216
#define WNI_CFG_WOWLAN_CHANNEL_SWITCH_ENABLE    217
#define WNI_CFG_WOWLAN_DEAUTH_ENABLE    218
#define WNI_CFG_WOWLAN_DISASSOC_ENABLE    219
#define WNI_CFG_WOWLAN_MAX_MISSED_BEACON    220
#define WNI_CFG_WOWLAN_MAX_SLEEP_PERIOD    221
#define WNI_CFG_BA_TIMEOUT    222
#define WNI_CFG_BA_THRESHOLD_HIGH    223
#define WNI_CFG_MAX_BA_BUFFERS    224
#define WNI_CFG_MAX_BA_SESSIONS    225
#define WNI_CFG_BA_AUTO_SETUP    226
#define WNI_CFG_ADDBA_REQ_DECLINE    227
#define WNI_CFG_DEL_ALL_RX_BA_SESSIONS_2_4_G_BTC    228
#define WNI_CFG_BG_SCAN_CHANNEL_LIST    229
#define WNI_CFG_MAX_MEDIUM_TIME    230
#define WNI_CFG_MAX_MPDUS_IN_AMPDU    231
#define WNI_CFG_IBSS_AUTO_BSSID    232
#define WNI_CFG_PROBE_REQ_ADDNIE_FLAG    233
#define WNI_CFG_PROBE_REQ_ADDNIE_DATA    234
#define WNI_CFG_PROBE_RSP_ADDNIE_FLAG    235
#define WNI_CFG_PROBE_RSP_ADDNIE_DATA1    236
#define WNI_CFG_PROBE_RSP_ADDNIE_DATA2    237
#define WNI_CFG_PROBE_RSP_ADDNIE_DATA3    238
#define WNI_CFG_ASSOC_RSP_ADDNIE_FLAG    239
#define WNI_CFG_ASSOC_RSP_ADDNIE_DATA    240
#define WNI_CFG_PROBE_REQ_ADDNP2PIE_FLAG    241
#define WNI_CFG_PROBE_REQ_ADDNP2PIE_DATA    242
#define WNI_CFG_PROBE_RSP_BCN_ADDNIE_FLAG    243
#define WNI_CFG_PROBE_RSP_BCN_ADDNIE_DATA    244
#define WNI_CFG_WPS_ENABLE    245
#define WNI_CFG_WPS_STATE    246
#define WNI_CFG_WPS_PROBE_REQ_FLAG    247
#define WNI_CFG_WPS_VERSION    248
#define WNI_CFG_WPS_REQUEST_TYPE    249
#define WNI_CFG_WPS_CFG_METHOD    250
#define WNI_CFG_WPS_UUID    251
#define WNI_CFG_WPS_PRIMARY_DEVICE_CATEGORY    252
#define WNI_CFG_WPS_PIMARY_DEVICE_OUI    253
#define WNI_CFG_WPS_DEVICE_SUB_CATEGORY    254
#define WNI_CFG_WPS_ASSOCIATION_STATE    255
#define WNI_CFG_WPS_CONFIGURATION_ERROR    256
#define WNI_CFG_WPS_DEVICE_PASSWORD_ID    257
#define WNI_CFG_WPS_ASSOC_METHOD    258
#define WNI_CFG_LOW_GAIN_OVERRIDE    259
#define WNI_CFG_ENABLE_PHY_AGC_LISTEN_MODE    260
#define WNI_CFG_RPE_POLLING_THRESHOLD    261
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC0_REG    262
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC1_REG    263
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC2_REG    264
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC3_REG    265
#define WNI_CFG_NO_OF_ONCHIP_REORDER_SESSIONS    266
#define WNI_CFG_SINGLE_TID_RC    267
#define WNI_CFG_RRM_ENABLED    268
#define WNI_CFG_RRM_OPERATING_CHAN_MAX    269
#define WNI_CFG_RRM_NON_OPERATING_CHAN_MAX    270
#define WNI_CFG_TX_PWR_CTRL_ENABLE    271
#define WNI_CFG_MCAST_BCAST_FILTER_SETTING    272
#define WNI_CFG_BTC_DHCP_BT_SLOTS_TO_BLOCK    273
#define WNI_CFG_DYNAMIC_PS_POLL_VALUE    274
#define WNI_CFG_PS_NULLDATA_AP_RESP_TIMEOUT    275
#define WNI_CFG_TELE_BCN_WAKEUP_EN    276
#define WNI_CFG_TELE_BCN_TRANS_LI    277
#define WNI_CFG_TELE_BCN_TRANS_LI_IDLE_BCNS    278
#define WNI_CFG_TELE_BCN_MAX_LI    279
#define WNI_CFG_TELE_BCN_MAX_LI_IDLE_BCNS    280
#define WNI_CFG_BTC_A2DP_DHCP_BT_SUB_INTERVALS    281
#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD    282
#define WNI_CFG_ASSOC_STA_LIMIT    283
#define WNI_CFG_SAP_CHANNEL_SELECT_START_CHANNEL    284
#define WNI_CFG_SAP_CHANNEL_SELECT_END_CHANNEL    285
#define WNI_CFG_SAP_CHANNEL_SELECT_OPERATING_BAND    286
#define WNI_CFG_AP_DATA_AVAIL_POLL_PERIOD    287
#define WNI_CFG_ENABLE_CLOSE_LOOP    288
#define WNI_CFG_ENABLE_LTE_COEX    289
#define WNI_CFG_AP_KEEP_ALIVE_TIMEOUT    290
#define WNI_CFG_GO_KEEP_ALIVE_TIMEOUT    291
#define WNI_CFG_ENABLE_MC_ADDR_LIST    292
#define WNI_CFG_ENABLE_UC_FILTER    293
#define WNI_CFG_ENABLE_LPWR_IMG_TRANSITION    294
#define WNI_CFG_ENABLE_MCC_ADAPTIVE_SCHED    295
#define WNI_CFG_DISABLE_LDPC_WITH_TXBF_AP    296
#define WNI_CFG_AP_LINK_MONITOR_TIMEOUT    297

/*
 * String parameter lengths 
 */

#define WNI_CFG_STA_ID_LEN    6
#define WNI_CFG_SSID_LEN    32
#define WNI_CFG_WEP_DEFAULT_KEY_1_LEN    13
#define WNI_CFG_WEP_DEFAULT_KEY_2_LEN    13
#define WNI_CFG_WEP_DEFAULT_KEY_3_LEN    13
#define WNI_CFG_WEP_DEFAULT_KEY_4_LEN    13
#define WNI_CFG_SUPPORTED_RATES_11B_LEN    4
#define WNI_CFG_SUPPORTED_RATES_11A_LEN    8
#define WNI_CFG_OPERATIONAL_RATE_SET_LEN    12
#define WNI_CFG_EXTENDED_OPERATIONAL_RATE_SET_LEN    8
#define WNI_CFG_PROPRIETARY_OPERATIONAL_RATE_SET_LEN    4
#define WNI_CFG_BSSID_LEN    6
#define WNI_CFG_VALID_CHANNEL_LIST_LEN    100
#define WNI_CFG_MANUFACTURER_OUI_LEN    3
#define WNI_CFG_MANUFACTURER_NAME_LEN    65
#define WNI_CFG_MODEL_NUMBER_LEN    33
#define WNI_CFG_MODEL_NAME_LEN    33
#define WNI_CFG_MANUFACTURER_PRODUCT_NAME_LEN    33
#define WNI_CFG_MANUFACTURER_PRODUCT_VERSION_LEN    33
#define WNI_CFG_MAX_TX_POWER_2_4_LEN    128
#define WNI_CFG_MAX_TX_POWER_5_LEN    128
#define WNI_CFG_AP_NODE_NAME_LEN    32
#define WNI_CFG_COUNTRY_CODE_LEN    3
#define WNI_CFG_EDCA_ANI_ACBK_LOCAL_LEN    20
#define WNI_CFG_EDCA_ANI_ACBE_LOCAL_LEN    20
#define WNI_CFG_EDCA_ANI_ACVI_LOCAL_LEN    20
#define WNI_CFG_EDCA_ANI_ACVO_LOCAL_LEN    20
#define WNI_CFG_EDCA_ANI_ACBK_LEN    20
#define WNI_CFG_EDCA_ANI_ACBE_LEN    20
#define WNI_CFG_EDCA_ANI_ACVI_LEN    20
#define WNI_CFG_EDCA_ANI_ACVO_LEN    20
#define WNI_CFG_EDCA_WME_ACBK_LOCAL_LEN    20
#define WNI_CFG_EDCA_WME_ACBE_LOCAL_LEN    20
#define WNI_CFG_EDCA_WME_ACVI_LOCAL_LEN    20
#define WNI_CFG_EDCA_WME_ACVO_LOCAL_LEN    20
#define WNI_CFG_EDCA_WME_ACBK_LEN    20
#define WNI_CFG_EDCA_WME_ACBE_LEN    20
#define WNI_CFG_EDCA_WME_ACVI_LEN    20
#define WNI_CFG_EDCA_WME_ACVO_LEN    20
#define WNI_CFG_EDCA_TIT_DEMO_ACBK_LOCAL_LEN    20
#define WNI_CFG_EDCA_TIT_DEMO_ACBE_LOCAL_LEN    20
#define WNI_CFG_EDCA_TIT_DEMO_ACVI_LOCAL_LEN    20
#define WNI_CFG_EDCA_TIT_DEMO_ACVO_LOCAL_LEN    20
#define WNI_CFG_EDCA_TIT_DEMO_ACBK_LEN    20
#define WNI_CFG_EDCA_TIT_DEMO_ACBE_LEN    20
#define WNI_CFG_EDCA_TIT_DEMO_ACVI_LEN    20
#define WNI_CFG_EDCA_TIT_DEMO_ACVO_LEN    20
#define WNI_CFG_RADAR_CHANNEL_LIST_LEN    20
#define WNI_CFG_SCAN_CONTROL_LIST_LEN    128
#define WNI_CFG_SUPPORTED_MCS_SET_LEN    16
#define WNI_CFG_BASIC_MCS_SET_LEN    16
#define WNI_CFG_CURRENT_MCS_SET_LEN    16
#define WNI_CFG_BG_SCAN_CHANNEL_LIST_LEN    100
#define WNI_CFG_PROBE_REQ_ADDNIE_DATA_LEN    255
#define WNI_CFG_PROBE_RSP_ADDNIE_DATA1_LEN    255
#define WNI_CFG_PROBE_RSP_ADDNIE_DATA2_LEN    255
#define WNI_CFG_PROBE_RSP_ADDNIE_DATA3_LEN    255
#define WNI_CFG_ASSOC_RSP_ADDNIE_DATA_LEN    255
#define WNI_CFG_PROBE_REQ_ADDNP2PIE_DATA_LEN    255
#define WNI_CFG_PROBE_RSP_BCN_ADDNIE_DATA_LEN    255
#define WNI_CFG_WPS_UUID_LEN    16

/*
 * Integer parameter min/max/default values 
 */

#define WNI_CFG_CF_POLLABLE_APMIN    0
#define WNI_CFG_CF_POLLABLE_APMAX    1
#define WNI_CFG_CF_POLLABLE_APDEF    0

#define WNI_CFG_CFP_PERIOD_STAMIN    0
#define WNI_CFG_CFP_PERIOD_STAMAX    255
#define WNI_CFG_CFP_PERIOD_STADEF    1

#define WNI_CFG_CFP_PERIOD_APMIN    0
#define WNI_CFG_CFP_PERIOD_APMAX    255
#define WNI_CFG_CFP_PERIOD_APDEF    1

#define WNI_CFG_CFP_MAX_DURATION_STAMIN    0
#define WNI_CFG_CFP_MAX_DURATION_STAMAX    65535
#define WNI_CFG_CFP_MAX_DURATION_STADEF    30000

#define WNI_CFG_CFP_MAX_DURATION_APMIN    0
#define WNI_CFG_CFP_MAX_DURATION_APMAX    65535
#define WNI_CFG_CFP_MAX_DURATION_APDEF    30000

#define WNI_CFG_BEACON_INTERVAL_STAMIN    0
#define WNI_CFG_BEACON_INTERVAL_STAMAX    65535
#define WNI_CFG_BEACON_INTERVAL_STADEF    100

#define WNI_CFG_BEACON_INTERVAL_APMIN    0
#define WNI_CFG_BEACON_INTERVAL_APMAX    65535
#define WNI_CFG_BEACON_INTERVAL_APDEF    100

#define WNI_CFG_DTIM_PERIOD_STAMIN    0
#define WNI_CFG_DTIM_PERIOD_STAMAX    65535
#define WNI_CFG_DTIM_PERIOD_STADEF    1

#define WNI_CFG_DTIM_PERIOD_APMIN    0
#define WNI_CFG_DTIM_PERIOD_APMAX    65535
#define WNI_CFG_DTIM_PERIOD_APDEF    1

#define WNI_CFG_WEP_KEY_LENGTH_STAMIN    5
#define WNI_CFG_WEP_KEY_LENGTH_STAMAX    13
#define WNI_CFG_WEP_KEY_LENGTH_STADEF    5

#define WNI_CFG_WEP_KEY_LENGTH_APMIN    5
#define WNI_CFG_WEP_KEY_LENGTH_APMAX    13
#define WNI_CFG_WEP_KEY_LENGTH_APDEF    5

#define WNI_CFG_WEP_KEY_LENGTH_5    5
#define WNI_CFG_WEP_KEY_LENGTH_13    13

#define WNI_CFG_WEP_DEFAULT_KEYID_STAMIN    0
#define WNI_CFG_WEP_DEFAULT_KEYID_STAMAX    3
#define WNI_CFG_WEP_DEFAULT_KEYID_STADEF    0

#define WNI_CFG_WEP_DEFAULT_KEYID_APMIN    0
#define WNI_CFG_WEP_DEFAULT_KEYID_APMAX    3
#define WNI_CFG_WEP_DEFAULT_KEYID_APDEF    0

#define WNI_CFG_WEP_DEFAULT_KEYID_0    0
#define WNI_CFG_WEP_DEFAULT_KEYID_1    1
#define WNI_CFG_WEP_DEFAULT_KEYID_2    2
#define WNI_CFG_WEP_DEFAULT_KEYID_3    3

#define WNI_CFG_EXCLUDE_UNENCRYPTED_STAMIN    0
#define WNI_CFG_EXCLUDE_UNENCRYPTED_STAMAX    1
#define WNI_CFG_EXCLUDE_UNENCRYPTED_STADEF    0

#define WNI_CFG_EXCLUDE_UNENCRYPTED_APMIN    0
#define WNI_CFG_EXCLUDE_UNENCRYPTED_APMAX    1
#define WNI_CFG_EXCLUDE_UNENCRYPTED_APDEF    0

#define WNI_CFG_RTS_THRESHOLD_STAMIN    0
#define WNI_CFG_RTS_THRESHOLD_STAMAX    2347
#define WNI_CFG_RTS_THRESHOLD_STADEF    2347

#define WNI_CFG_RTS_THRESHOLD_APMIN    0
#define WNI_CFG_RTS_THRESHOLD_APMAX    2347
#define WNI_CFG_RTS_THRESHOLD_APDEF    2347

#define WNI_CFG_SHORT_RETRY_LIMIT_STAMIN    0
#define WNI_CFG_SHORT_RETRY_LIMIT_STAMAX    255
#define WNI_CFG_SHORT_RETRY_LIMIT_STADEF    6

#define WNI_CFG_SHORT_RETRY_LIMIT_APMIN    0
#define WNI_CFG_SHORT_RETRY_LIMIT_APMAX    255
#define WNI_CFG_SHORT_RETRY_LIMIT_APDEF    6

#define WNI_CFG_LONG_RETRY_LIMIT_STAMIN    0
#define WNI_CFG_LONG_RETRY_LIMIT_STAMAX    255
#define WNI_CFG_LONG_RETRY_LIMIT_STADEF    6

#define WNI_CFG_LONG_RETRY_LIMIT_APMIN    0
#define WNI_CFG_LONG_RETRY_LIMIT_APMAX    255
#define WNI_CFG_LONG_RETRY_LIMIT_APDEF    6

#define WNI_CFG_FRAGMENTATION_THRESHOLD_STAMIN    256
#define WNI_CFG_FRAGMENTATION_THRESHOLD_STAMAX    8000
#define WNI_CFG_FRAGMENTATION_THRESHOLD_STADEF    8000

#define WNI_CFG_FRAGMENTATION_THRESHOLD_APMIN    256
#define WNI_CFG_FRAGMENTATION_THRESHOLD_APMAX    8000
#define WNI_CFG_FRAGMENTATION_THRESHOLD_APDEF    8000

#define WNI_CFG_ACTIVE_MINIMUM_CHANNEL_TIME_STAMIN    0
#define WNI_CFG_ACTIVE_MINIMUM_CHANNEL_TIME_STAMAX    65535
#define WNI_CFG_ACTIVE_MINIMUM_CHANNEL_TIME_STADEF    20

#define WNI_CFG_ACTIVE_MINIMUM_CHANNEL_TIME_APMIN    0
#define WNI_CFG_ACTIVE_MINIMUM_CHANNEL_TIME_APMAX    65535
#define WNI_CFG_ACTIVE_MINIMUM_CHANNEL_TIME_APDEF    20

#define WNI_CFG_ACTIVE_MAXIMUM_CHANNEL_TIME_STAMIN    0
#define WNI_CFG_ACTIVE_MAXIMUM_CHANNEL_TIME_STAMAX    65535
#define WNI_CFG_ACTIVE_MAXIMUM_CHANNEL_TIME_STADEF    40

#define WNI_CFG_ACTIVE_MAXIMUM_CHANNEL_TIME_APMIN    0
#define WNI_CFG_ACTIVE_MAXIMUM_CHANNEL_TIME_APMAX    65535
#define WNI_CFG_ACTIVE_MAXIMUM_CHANNEL_TIME_APDEF    40

#define WNI_CFG_PASSIVE_MINIMUM_CHANNEL_TIME_STAMIN    0
#define WNI_CFG_PASSIVE_MINIMUM_CHANNEL_TIME_STAMAX    65535
#define WNI_CFG_PASSIVE_MINIMUM_CHANNEL_TIME_STADEF    60

#define WNI_CFG_PASSIVE_MINIMUM_CHANNEL_TIME_APMIN    0
#define WNI_CFG_PASSIVE_MINIMUM_CHANNEL_TIME_APMAX    65535
#define WNI_CFG_PASSIVE_MINIMUM_CHANNEL_TIME_APDEF    60

#define WNI_CFG_PASSIVE_MAXIMUM_CHANNEL_TIME_STAMIN    0
#define WNI_CFG_PASSIVE_MAXIMUM_CHANNEL_TIME_STAMAX    65535
#define WNI_CFG_PASSIVE_MAXIMUM_CHANNEL_TIME_STADEF    110

#define WNI_CFG_PASSIVE_MAXIMUM_CHANNEL_TIME_APMIN    0
#define WNI_CFG_PASSIVE_MAXIMUM_CHANNEL_TIME_APMAX    65535
#define WNI_CFG_PASSIVE_MAXIMUM_CHANNEL_TIME_APDEF    110

#define WNI_CFG_JOIN_FAILURE_TIMEOUT_STAMIN    0
#define WNI_CFG_JOIN_FAILURE_TIMEOUT_STAMAX    65535
#define WNI_CFG_JOIN_FAILURE_TIMEOUT_STADEF    3000

#define WNI_CFG_JOIN_FAILURE_TIMEOUT_APMIN    0
#define WNI_CFG_JOIN_FAILURE_TIMEOUT_APMAX    65535
#define WNI_CFG_JOIN_FAILURE_TIMEOUT_APDEF    3000

#define WNI_CFG_AUTHENTICATE_FAILURE_TIMEOUT_STAMIN    0
#define WNI_CFG_AUTHENTICATE_FAILURE_TIMEOUT_STAMAX    65535
#define WNI_CFG_AUTHENTICATE_FAILURE_TIMEOUT_STADEF    1000

#define WNI_CFG_AUTHENTICATE_FAILURE_TIMEOUT_APMIN    0
#define WNI_CFG_AUTHENTICATE_FAILURE_TIMEOUT_APMAX    65535
#define WNI_CFG_AUTHENTICATE_FAILURE_TIMEOUT_APDEF    1000

#define WNI_CFG_AUTHENTICATE_RSP_TIMEOUT_STAMIN    0
#define WNI_CFG_AUTHENTICATE_RSP_TIMEOUT_STAMAX    65535
#define WNI_CFG_AUTHENTICATE_RSP_TIMEOUT_STADEF    1000

#define WNI_CFG_AUTHENTICATE_RSP_TIMEOUT_APMIN    0
#define WNI_CFG_AUTHENTICATE_RSP_TIMEOUT_APMAX    65535
#define WNI_CFG_AUTHENTICATE_RSP_TIMEOUT_APDEF    1000

#define WNI_CFG_ASSOCIATION_FAILURE_TIMEOUT_STAMIN    0
#define WNI_CFG_ASSOCIATION_FAILURE_TIMEOUT_STAMAX    65535
#define WNI_CFG_ASSOCIATION_FAILURE_TIMEOUT_STADEF    2000

#define WNI_CFG_ASSOCIATION_FAILURE_TIMEOUT_APMIN    0
#define WNI_CFG_ASSOCIATION_FAILURE_TIMEOUT_APMAX    65535
#define WNI_CFG_ASSOCIATION_FAILURE_TIMEOUT_APDEF    3000

#define WNI_CFG_REASSOCIATION_FAILURE_TIMEOUT_STAMIN    0
#define WNI_CFG_REASSOCIATION_FAILURE_TIMEOUT_STAMAX    65535
#define WNI_CFG_REASSOCIATION_FAILURE_TIMEOUT_STADEF    1000

#define WNI_CFG_REASSOCIATION_FAILURE_TIMEOUT_APMIN    0
#define WNI_CFG_REASSOCIATION_FAILURE_TIMEOUT_APMAX    65535
#define WNI_CFG_REASSOCIATION_FAILURE_TIMEOUT_APDEF    3000

#define WNI_CFG_RA_PERIODICITY_TIMEOUT_IN_PS_STAMIN    0
#define WNI_CFG_RA_PERIODICITY_TIMEOUT_IN_PS_STAMAX    65535
#define WNI_CFG_RA_PERIODICITY_TIMEOUT_IN_PS_STADEF    1000

#define WNI_CFG_PS_ENABLE_BCN_FILTER_STAMIN    0
#define WNI_CFG_PS_ENABLE_BCN_FILTER_STAMAX    1
#define WNI_CFG_PS_ENABLE_BCN_FILTER_STADEF    1

#define WNI_CFG_PS_ENABLE_HEART_BEAT_STAMIN    0
#define WNI_CFG_PS_ENABLE_HEART_BEAT_STAMAX    1
#define WNI_CFG_PS_ENABLE_HEART_BEAT_STADEF    1

#define WNI_CFG_PS_ENABLE_RSSI_MONITOR_STAMIN    0
#define WNI_CFG_PS_ENABLE_RSSI_MONITOR_STAMAX    1
#define WNI_CFG_PS_ENABLE_RSSI_MONITOR_STADEF    0

#define WNI_CFG_PS_DATA_INACTIVITY_TIMEOUT_STAMIN    1
#define WNI_CFG_PS_DATA_INACTIVITY_TIMEOUT_STAMAX    255
#define WNI_CFG_PS_DATA_INACTIVITY_TIMEOUT_STADEF    20

#define WNI_CFG_RF_SETTLING_TIME_CLK_STAMIN    0
#define WNI_CFG_RF_SETTLING_TIME_CLK_STAMAX    60000
#define WNI_CFG_RF_SETTLING_TIME_CLK_STADEF    1500

#define WNI_CFG_PHY_MODE_STAMIN    0
#define WNI_CFG_PHY_MODE_STAMAX    3
#define WNI_CFG_PHY_MODE_STADEF    0

#define WNI_CFG_PHY_MODE_APMIN    0
#define WNI_CFG_PHY_MODE_APMAX    3
#define WNI_CFG_PHY_MODE_APDEF    0

#define WNI_CFG_PHY_MODE_11A    0
#define WNI_CFG_PHY_MODE_11B    1
#define WNI_CFG_PHY_MODE_11G    2
#define WNI_CFG_PHY_MODE_NONE    3

#define WNI_CFG_DOT11_MODE_STAMIN    0
#define WNI_CFG_DOT11_MODE_STAMAX    11
#define WNI_CFG_DOT11_MODE_STADEF    0

#define WNI_CFG_DOT11_MODE_APMIN    0
#define WNI_CFG_DOT11_MODE_APMAX    11
#define WNI_CFG_DOT11_MODE_APDEF    0

#define WNI_CFG_DOT11_MODE_ALL    0
#define WNI_CFG_DOT11_MODE_11A    1
#define WNI_CFG_DOT11_MODE_11B    2
#define WNI_CFG_DOT11_MODE_11G    3
#define WNI_CFG_DOT11_MODE_11N    4
#define WNI_CFG_DOT11_MODE_POLARIS    5
#define WNI_CFG_DOT11_MODE_TITAN    6
#define WNI_CFG_DOT11_MODE_TAURUS    7
#define WNI_CFG_DOT11_MODE_11G_ONLY    8
#define WNI_CFG_DOT11_MODE_11N_ONLY    9
#define WNI_CFG_DOT11_MODE_11AC    10
#define WNI_CFG_DOT11_MODE_11AC_ONLY    11

#define WNI_CFG_LISTEN_INTERVAL_STAMIN    0
#define WNI_CFG_LISTEN_INTERVAL_STAMAX    65535
#define WNI_CFG_LISTEN_INTERVAL_STADEF    1

#define WNI_CFG_LISTEN_INTERVAL_APMIN    0
#define WNI_CFG_LISTEN_INTERVAL_APMAX    65535
#define WNI_CFG_LISTEN_INTERVAL_APDEF    1

#define WNI_CFG_CURRENT_CHANNEL_STAMIN    0
#define WNI_CFG_CURRENT_CHANNEL_STAMAX    165
#define WNI_CFG_CURRENT_CHANNEL_STADEF    1

#define WNI_CFG_CURRENT_CHANNEL_APMIN    0
#define WNI_CFG_CURRENT_CHANNEL_APMAX    165
#define WNI_CFG_CURRENT_CHANNEL_APDEF    1

#define WNI_CFG_DEFAULT_RATE_INDEX_5GHZ_STAMIN    0
#define WNI_CFG_DEFAULT_RATE_INDEX_5GHZ_STAMAX    11
#define WNI_CFG_DEFAULT_RATE_INDEX_5GHZ_STADEF    5

#define WNI_CFG_DEFAULT_RATE_INDEX_5GHZ_APMIN    0
#define WNI_CFG_DEFAULT_RATE_INDEX_5GHZ_APMAX    11
#define WNI_CFG_DEFAULT_RATE_INDEX_5GHZ_APDEF    5

#define WNI_CFG_DEFAULT_RATE_INDEX_24GHZ_STAMIN    0
#define WNI_CFG_DEFAULT_RATE_INDEX_24GHZ_STAMAX    31
#define WNI_CFG_DEFAULT_RATE_INDEX_24GHZ_STADEF    1

#define WNI_CFG_DEFAULT_RATE_INDEX_24GHZ_APMIN    0
#define WNI_CFG_DEFAULT_RATE_INDEX_24GHZ_APMAX    31
#define WNI_CFG_DEFAULT_RATE_INDEX_24GHZ_APDEF    1

#define WNI_CFG_RATE_ADAPTATION_TYPE_STAMIN    0
#define WNI_CFG_RATE_ADAPTATION_TYPE_STAMAX    2
#define WNI_CFG_RATE_ADAPTATION_TYPE_STADEF    1

#define WNI_CFG_RATE_ADAPTATION_TYPE_APMIN    0
#define WNI_CFG_RATE_ADAPTATION_TYPE_APMAX    2
#define WNI_CFG_RATE_ADAPTATION_TYPE_APDEF    1

#define WNI_CFG_RATE_ADAPTATION_TYPE_FIXED    0
#define WNI_CFG_RATE_ADAPTATION_TYPE_AUTO    1
#define WNI_CFG_RATE_ADAPTATION_TYPE_SNR_BASED    2

#define WNI_CFG_FIXED_RATE_STAMIN    0
#define WNI_CFG_FIXED_RATE_STAMAX    31
#define WNI_CFG_FIXED_RATE_STADEF    0

#define WNI_CFG_FIXED_RATE_APMIN    0
#define WNI_CFG_FIXED_RATE_APMAX    31
#define WNI_CFG_FIXED_RATE_APDEF    0

#define WNI_CFG_FIXED_RATE_AUTO    0
#define WNI_CFG_FIXED_RATE_1MBPS    1
#define WNI_CFG_FIXED_RATE_2MBPS    2
#define WNI_CFG_FIXED_RATE_5_5MBPS    3
#define WNI_CFG_FIXED_RATE_11MBPS    4
#define WNI_CFG_FIXED_RATE_6MBPS    5
#define WNI_CFG_FIXED_RATE_9MBPS    6
#define WNI_CFG_FIXED_RATE_12MBPS    7
#define WNI_CFG_FIXED_RATE_18MBPS    8
#define WNI_CFG_FIXED_RATE_24MBPS    9
#define WNI_CFG_FIXED_RATE_36MBPS    10
#define WNI_CFG_FIXED_RATE_48MBPS    11
#define WNI_CFG_FIXED_RATE_54MBPS    12
#define WNI_CFG_FIXED_RATE_6_5MBPS_MCS0_20MHZ_SIMO    13
#define WNI_CFG_FIXED_RATE_13MBPS_MCS1_20MHZ_SIMO    14
#define WNI_CFG_FIXED_RATE_19_5MBPS_MCS2_20MHZ_SIMO    15
#define WNI_CFG_FIXED_RATE_26MBPS_MCS3_20MHZ_SIMO    16
#define WNI_CFG_FIXED_RATE_39MBPS_MCS4_20MHZ_SIMO    17
#define WNI_CFG_FIXED_RATE_52MBPS_MCS5_20MHZ_SIMO    18
#define WNI_CFG_FIXED_RATE_58_5MBPS_MCS6_20MHZ_SIMO    19
#define WNI_CFG_FIXED_RATE_65MBPS_MCS7_20MHZ_SIMO    20
#define WNI_CFG_FIXED_RATE_7_2MBPS_MCS0_20MHZ_SIMO_SGI    21
#define WNI_CFG_FIXED_RATE_14_4MBPS_MCS1_20MHZ_SIMO_SGI    22
#define WNI_CFG_FIXED_RATE_21_7MBPS_MCS2_20MHZ_SIMO_SGI    23
#define WNI_CFG_FIXED_RATE_28_9MBPS_MCS3_20MHZ_SIMO_SGI    24
#define WNI_CFG_FIXED_RATE_43_3MBPS_MCS4_20MHZ_SIMO_SGI    25
#define WNI_CFG_FIXED_RATE_57_8MBPS_MCS5_20MHZ_SIMO_SGI    26
#define WNI_CFG_FIXED_RATE_65MBPS_MCS6_20MHZ_SIMO_SGI    27
#define WNI_CFG_FIXED_RATE_72_2MBPS_MCS7_20MHZ_SIMO_SGI    28
#define WNI_CFG_FIXED_RATE_0_25MBPS_SLR_20MHZ_SIMO    29
#define WNI_CFG_FIXED_RATE_0_5MBPS_SLR_20MHZ_SIMO    30
#define WNI_CFG_FIXED_RATE_68_25MBPS_QC_PROP_20MHZ_SIMO    31

#define WNI_CFG_FIXED_RATE_MULTICAST_24GHZ_STAMIN    0
#define WNI_CFG_FIXED_RATE_MULTICAST_24GHZ_STAMAX    31
#define WNI_CFG_FIXED_RATE_MULTICAST_24GHZ_STADEF    1

#define WNI_CFG_FIXED_RATE_MULTICAST_24GHZ_APMIN    0
#define WNI_CFG_FIXED_RATE_MULTICAST_24GHZ_APMAX    31
#define WNI_CFG_FIXED_RATE_MULTICAST_24GHZ_APDEF    1

#define WNI_CFG_FIXED_RATE_MULTICAST_5GHZ_STAMIN    0
#define WNI_CFG_FIXED_RATE_MULTICAST_5GHZ_STAMAX    31
#define WNI_CFG_FIXED_RATE_MULTICAST_5GHZ_STADEF    5

#define WNI_CFG_FIXED_RATE_MULTICAST_5GHZ_APMIN    0
#define WNI_CFG_FIXED_RATE_MULTICAST_5GHZ_APMAX    31
#define WNI_CFG_FIXED_RATE_MULTICAST_5GHZ_APDEF    5

#define WNI_CFG_RETRYRATE_POLICY_STAMIN    0
#define WNI_CFG_RETRYRATE_POLICY_STAMAX    255
#define WNI_CFG_RETRYRATE_POLICY_STADEF    4

#define WNI_CFG_RETRYRATE_POLICY_APMIN    0
#define WNI_CFG_RETRYRATE_POLICY_APMAX    255
#define WNI_CFG_RETRYRATE_POLICY_APDEF    4

#define WNI_CFG_RETRYRATE_POLICY_MIN_SUPPORTED    0
#define WNI_CFG_RETRYRATE_POLICY_PRIMARY    1
#define WNI_CFG_RETRYRATE_POLICY_RESERVED    2
#define WNI_CFG_RETRYRATE_POLICY_CLOSEST    3
#define WNI_CFG_RETRYRATE_POLICY_AUTOSELECT    4
#define WNI_CFG_RETRYRATE_POLICY_MAX    5

#define WNI_CFG_RETRYRATE_SECONDARY_STAMIN    0
#define WNI_CFG_RETRYRATE_SECONDARY_STAMAX    255
#define WNI_CFG_RETRYRATE_SECONDARY_STADEF    0

#define WNI_CFG_RETRYRATE_SECONDARY_APMIN    0
#define WNI_CFG_RETRYRATE_SECONDARY_APMAX    255
#define WNI_CFG_RETRYRATE_SECONDARY_APDEF    0

#define WNI_CFG_RETRYRATE_TERTIARY_STAMIN    0
#define WNI_CFG_RETRYRATE_TERTIARY_STAMAX    255
#define WNI_CFG_RETRYRATE_TERTIARY_STADEF    0

#define WNI_CFG_RETRYRATE_TERTIARY_APMIN    0
#define WNI_CFG_RETRYRATE_TERTIARY_APMAX    255
#define WNI_CFG_RETRYRATE_TERTIARY_APDEF    0

#define WNI_CFG_APSD_ENABLED_STAMIN    0
#define WNI_CFG_APSD_ENABLED_STAMAX    1
#define WNI_CFG_APSD_ENABLED_STADEF    0

#define WNI_CFG_APSD_ENABLED_APMIN    0
#define WNI_CFG_APSD_ENABLED_APMAX    1
#define WNI_CFG_APSD_ENABLED_APDEF    0

#define WNI_CFG_SHARED_KEY_AUTH_ENABLE_STAMIN    0
#define WNI_CFG_SHARED_KEY_AUTH_ENABLE_STAMAX    1
#define WNI_CFG_SHARED_KEY_AUTH_ENABLE_STADEF    1

#define WNI_CFG_SHARED_KEY_AUTH_ENABLE_APMIN    0
#define WNI_CFG_SHARED_KEY_AUTH_ENABLE_APMAX    1
#define WNI_CFG_SHARED_KEY_AUTH_ENABLE_APDEF    1

#define WNI_CFG_OPEN_SYSTEM_AUTH_ENABLE_STAMIN    0
#define WNI_CFG_OPEN_SYSTEM_AUTH_ENABLE_STAMAX    1
#define WNI_CFG_OPEN_SYSTEM_AUTH_ENABLE_STADEF    1

#define WNI_CFG_OPEN_SYSTEM_AUTH_ENABLE_APMIN    0
#define WNI_CFG_OPEN_SYSTEM_AUTH_ENABLE_APMAX    1
#define WNI_CFG_OPEN_SYSTEM_AUTH_ENABLE_APDEF    1

#define WNI_CFG_AUTHENTICATION_TYPE_STAMIN    0
#define WNI_CFG_AUTHENTICATION_TYPE_STAMAX    65535
#define WNI_CFG_AUTHENTICATION_TYPE_STADEF    0

#define WNI_CFG_AUTHENTICATION_TYPE_APMIN    0
#define WNI_CFG_AUTHENTICATION_TYPE_APMAX    65535
#define WNI_CFG_AUTHENTICATION_TYPE_APDEF    0

#define WNI_CFG_CF_POLL_REQUEST_APMIN    0
#define WNI_CFG_CF_POLL_REQUEST_APMAX    1
#define WNI_CFG_CF_POLL_REQUEST_APDEF    0

#define WNI_CFG_PRIVACY_ENABLED_STAMIN    0
#define WNI_CFG_PRIVACY_ENABLED_STAMAX    1
#define WNI_CFG_PRIVACY_ENABLED_STADEF    0

#define WNI_CFG_PRIVACY_ENABLED_APMIN    0
#define WNI_CFG_PRIVACY_ENABLED_APMAX    1
#define WNI_CFG_PRIVACY_ENABLED_APDEF    0

#define WNI_CFG_SHORT_PREAMBLE_STAMIN    0
#define WNI_CFG_SHORT_PREAMBLE_STAMAX    1
#define WNI_CFG_SHORT_PREAMBLE_STADEF    1

#define WNI_CFG_SHORT_PREAMBLE_APMIN    0
#define WNI_CFG_SHORT_PREAMBLE_APMAX    1
#define WNI_CFG_SHORT_PREAMBLE_APDEF    1

#define WNI_CFG_SHORT_SLOT_TIME_STAMIN    0
#define WNI_CFG_SHORT_SLOT_TIME_STAMAX    1
#define WNI_CFG_SHORT_SLOT_TIME_STADEF    1

#define WNI_CFG_SHORT_SLOT_TIME_APMIN    0
#define WNI_CFG_SHORT_SLOT_TIME_APMAX    1
#define WNI_CFG_SHORT_SLOT_TIME_APDEF    0

#define WNI_CFG_ACCEPT_SHORT_SLOT_ASSOC_ONLY_STAMIN    0
#define WNI_CFG_ACCEPT_SHORT_SLOT_ASSOC_ONLY_STAMAX    1
#define WNI_CFG_ACCEPT_SHORT_SLOT_ASSOC_ONLY_STADEF    0

#define WNI_CFG_ACCEPT_SHORT_SLOT_ASSOC_ONLY_APMIN    0
#define WNI_CFG_ACCEPT_SHORT_SLOT_ASSOC_ONLY_APMAX    1
#define WNI_CFG_ACCEPT_SHORT_SLOT_ASSOC_ONLY_APDEF    0

#define WNI_CFG_QOS_ENABLED_STAMIN    0
#define WNI_CFG_QOS_ENABLED_STAMAX    1
#define WNI_CFG_QOS_ENABLED_STADEF    0

#define WNI_CFG_QOS_ENABLED_APMIN    0
#define WNI_CFG_QOS_ENABLED_APMAX    1
#define WNI_CFG_QOS_ENABLED_APDEF    0

#define WNI_CFG_HCF_ENABLED_STAMIN    0
#define WNI_CFG_HCF_ENABLED_STAMAX    1
#define WNI_CFG_HCF_ENABLED_STADEF    0

#define WNI_CFG_HCF_ENABLED_APMIN    0
#define WNI_CFG_HCF_ENABLED_APMAX    1
#define WNI_CFG_HCF_ENABLED_APDEF    0

#define WNI_CFG_RSN_ENABLED_STAMIN    0
#define WNI_CFG_RSN_ENABLED_STAMAX    1
#define WNI_CFG_RSN_ENABLED_STADEF    0

#define WNI_CFG_RSN_ENABLED_APMIN    0
#define WNI_CFG_RSN_ENABLED_APMAX    1
#define WNI_CFG_RSN_ENABLED_APDEF    0

#define WNI_CFG_BACKGROUND_SCAN_PERIOD_STAMIN    0
#define WNI_CFG_BACKGROUND_SCAN_PERIOD_STAMAX    180000
#define WNI_CFG_BACKGROUND_SCAN_PERIOD_STADEF    5000

#define WNI_CFG_BACKGROUND_SCAN_PERIOD_APMIN    0
#define WNI_CFG_BACKGROUND_SCAN_PERIOD_APMAX    18000
#define WNI_CFG_BACKGROUND_SCAN_PERIOD_APDEF    5000

#define WNI_CFG_MAX_NUM_PRE_AUTH_STAMIN    0
#define WNI_CFG_MAX_NUM_PRE_AUTH_STAMAX    256
#define WNI_CFG_MAX_NUM_PRE_AUTH_STADEF    64

#define WNI_CFG_MAX_NUM_PRE_AUTH_APMIN    0
#define WNI_CFG_MAX_NUM_PRE_AUTH_APMAX    256
#define WNI_CFG_MAX_NUM_PRE_AUTH_APDEF    64

#define WNI_CFG_PREAUTH_CLNUP_TIMEOUT_APMIN    0
#define WNI_CFG_PREAUTH_CLNUP_TIMEOUT_APMAX    120000
#define WNI_CFG_PREAUTH_CLNUP_TIMEOUT_APDEF    30000

#define WNI_CFG_RELEASE_AID_TIMEOUT_APMIN    0
#define WNI_CFG_RELEASE_AID_TIMEOUT_APMAX    100000
#define WNI_CFG_RELEASE_AID_TIMEOUT_APDEF    1000

#define WNI_CFG_HEART_BEAT_THRESHOLD_STAMIN    0
#define WNI_CFG_HEART_BEAT_THRESHOLD_STAMAX    65535
#define WNI_CFG_HEART_BEAT_THRESHOLD_STADEF    40

#define WNI_CFG_PROBE_AFTER_HB_FAIL_TIMEOUT_STAMIN    10
#define WNI_CFG_PROBE_AFTER_HB_FAIL_TIMEOUT_STAMAX    10000
#define WNI_CFG_PROBE_AFTER_HB_FAIL_TIMEOUT_STADEF    40

#define WNI_CFG_PROBE_AFTER_HB_FAIL_TIMEOUT_APMIN    10
#define WNI_CFG_PROBE_AFTER_HB_FAIL_TIMEOUT_APMAX    10000
#define WNI_CFG_PROBE_AFTER_HB_FAIL_TIMEOUT_APDEF    40

#define WNI_CFG_11D_ENABLED_STAMIN    0
#define WNI_CFG_11D_ENABLED_STAMAX    1
#define WNI_CFG_11D_ENABLED_STADEF    1

#define WNI_CFG_11D_ENABLED_APMIN    0
#define WNI_CFG_11D_ENABLED_APMAX    1
#define WNI_CFG_11D_ENABLED_APDEF    0

#define WNI_CFG_NETWORK_DENSITY_STAMIN    0
#define WNI_CFG_NETWORK_DENSITY_STAMAX    3
#define WNI_CFG_NETWORK_DENSITY_STADEF    3

#define WNI_CFG_NETWORK_DENSITY_APMIN    0
#define WNI_CFG_NETWORK_DENSITY_APMAX    3
#define WNI_CFG_NETWORK_DENSITY_APDEF    0

#define WNI_CFG_NETWORK_DENSITY_LOW    0
#define WNI_CFG_NETWORK_DENSITY_MEDIUM    1
#define WNI_CFG_NETWORK_DENSITY_HIGH    2
#define WNI_CFG_NETWORK_DENSITY_ADAPTIVE    3

#define WNI_CFG_ADAPTIVE_THRESHOLD_ALGORITHM_STAMIN    1
#define WNI_CFG_ADAPTIVE_THRESHOLD_ALGORITHM_STAMAX    2
#define WNI_CFG_ADAPTIVE_THRESHOLD_ALGORITHM_STADEF    2

#define WNI_CFG_ADAPTIVE_THRESHOLD_ALGORITHM_APMIN    1
#define WNI_CFG_ADAPTIVE_THRESHOLD_ALGORITHM_APMAX    2
#define WNI_CFG_ADAPTIVE_THRESHOLD_ALGORITHM_APDEF    2

#define WNI_CFG_ADAPTIVE_THRESHOLD_ALGORITHM_CARRIER    1
#define WNI_CFG_ADAPTIVE_THRESHOLD_ALGORITHM_CORRELATION    2

#define WNI_CFG_CURRENT_TX_ANTENNA_STAMIN    1
#define WNI_CFG_CURRENT_TX_ANTENNA_STAMAX    1
#define WNI_CFG_CURRENT_TX_ANTENNA_STADEF    1

#define WNI_CFG_CURRENT_TX_ANTENNA_APMIN    1
#define WNI_CFG_CURRENT_TX_ANTENNA_APMAX    2
#define WNI_CFG_CURRENT_TX_ANTENNA_APDEF    2

#define WNI_CFG_CURRENT_RX_ANTENNA_STAMIN    1
#define WNI_CFG_CURRENT_RX_ANTENNA_STAMAX    2
#define WNI_CFG_CURRENT_RX_ANTENNA_STADEF    2

#define WNI_CFG_CURRENT_RX_ANTENNA_APMIN    1
#define WNI_CFG_CURRENT_RX_ANTENNA_APMAX    3
#define WNI_CFG_CURRENT_RX_ANTENNA_APDEF    3

#define WNI_CFG_CURRENT_TX_POWER_LEVEL_STAMIN    0
#define WNI_CFG_CURRENT_TX_POWER_LEVEL_STAMAX    128
#define WNI_CFG_CURRENT_TX_POWER_LEVEL_STADEF    27

#define WNI_CFG_CURRENT_TX_POWER_LEVEL_APMIN    0
#define WNI_CFG_CURRENT_TX_POWER_LEVEL_APMAX    128
#define WNI_CFG_CURRENT_TX_POWER_LEVEL_APDEF    27

#define WNI_CFG_POWER_STATE_PER_CHAIN_STAMIN    0
#define WNI_CFG_POWER_STATE_PER_CHAIN_STAMAX    65535
#define WNI_CFG_POWER_STATE_PER_CHAIN_STADEF    785

#define WNI_CFG_POWER_STATE_PER_CHAIN_APMIN    0
#define WNI_CFG_POWER_STATE_PER_CHAIN_APMAX    65535
#define WNI_CFG_POWER_STATE_PER_CHAIN_APDEF    785

#define WNI_CFG_POWER_STATE_PER_CHAIN_OFF    0
#define WNI_CFG_POWER_STATE_PER_CHAIN_ON    1
#define WNI_CFG_POWER_STATE_PER_CHAIN_TX    2
#define WNI_CFG_POWER_STATE_PER_CHAIN_RX    3
#define WNI_CFG_POWER_STATE_PER_CHAIN_MASK    15
#define WNI_CFG_POWER_STATE_PER_CHAIN_CHAIN_0_OFFSET    0
#define WNI_CFG_POWER_STATE_PER_CHAIN_CHAIN_1_OFFSET    4
#define WNI_CFG_POWER_STATE_PER_CHAIN_CHAIN_2_OFFSET    8

#define WNI_CFG_NEW_BSS_FOUND_IND_STAMIN    0
#define WNI_CFG_NEW_BSS_FOUND_IND_STAMAX    1
#define WNI_CFG_NEW_BSS_FOUND_IND_STADEF    0

#define WNI_CFG_NEW_BSS_FOUND_IND_APMIN    0
#define WNI_CFG_NEW_BSS_FOUND_IND_APMAX    1
#define WNI_CFG_NEW_BSS_FOUND_IND_APDEF    0

#define WNI_CFG_PROPRIETARY_ANI_FEATURES_ENABLED_STAMIN    0
#define WNI_CFG_PROPRIETARY_ANI_FEATURES_ENABLED_STAMAX    1
#define WNI_CFG_PROPRIETARY_ANI_FEATURES_ENABLED_STADEF    0

#define WNI_CFG_PROPRIETARY_ANI_FEATURES_ENABLED_APMIN    0
#define WNI_CFG_PROPRIETARY_ANI_FEATURES_ENABLED_APMAX    1
#define WNI_CFG_PROPRIETARY_ANI_FEATURES_ENABLED_APDEF    0

#define WNI_CFG_PROPRIETARY_RATES_ENABLED_STAMIN    0
#define WNI_CFG_PROPRIETARY_RATES_ENABLED_STAMAX    1
#define WNI_CFG_PROPRIETARY_RATES_ENABLED_STADEF    0

#define WNI_CFG_PROPRIETARY_RATES_ENABLED_APMIN    0
#define WNI_CFG_PROPRIETARY_RATES_ENABLED_APMAX    1
#define WNI_CFG_PROPRIETARY_RATES_ENABLED_APDEF    0

#define WNI_CFG_11H_ENABLED_STAMIN    0
#define WNI_CFG_11H_ENABLED_STAMAX    1
#define WNI_CFG_11H_ENABLED_STADEF    1

#define WNI_CFG_11H_ENABLED_APMIN    0
#define WNI_CFG_11H_ENABLED_APMAX    1
#define WNI_CFG_11H_ENABLED_APDEF    1

#define WNI_CFG_WT_CNF_TIMEOUT_STAMIN    10
#define WNI_CFG_WT_CNF_TIMEOUT_STAMAX    3000
#define WNI_CFG_WT_CNF_TIMEOUT_STADEF    1000

#define WNI_CFG_WT_CNF_TIMEOUT_APMIN    10
#define WNI_CFG_WT_CNF_TIMEOUT_APMAX    3000
#define WNI_CFG_WT_CNF_TIMEOUT_APDEF    1000

#define WNI_CFG_KEEPALIVE_TIMEOUT_STAMIN    0
#define WNI_CFG_KEEPALIVE_TIMEOUT_STAMAX    3600000
#define WNI_CFG_KEEPALIVE_TIMEOUT_STADEF    0

#define WNI_CFG_KEEPALIVE_TIMEOUT_APMIN    0
#define WNI_CFG_KEEPALIVE_TIMEOUT_APMAX    3600000
#define WNI_CFG_KEEPALIVE_TIMEOUT_APDEF    3000

#define WNI_CFG_PROXIMITY_STAMIN    0
#define WNI_CFG_PROXIMITY_STAMAX    1
#define WNI_CFG_PROXIMITY_STADEF    0

#define WNI_CFG_PROXIMITY_APMIN    0
#define WNI_CFG_PROXIMITY_APMAX    1
#define WNI_CFG_PROXIMITY_APDEF    0

#define WNI_CFG_PROXIMITY_OFF    0
#define WNI_CFG_PROXIMITY_ON    1

#define WNI_CFG_LOG_LEVEL_STAMIN    0
#define WNI_CFG_LOG_LEVEL_STAMAX    7
#define WNI_CFG_LOG_LEVEL_STADEF    4

#define WNI_CFG_LOG_LEVEL_APMIN    0
#define WNI_CFG_LOG_LEVEL_APMAX    7
#define WNI_CFG_LOG_LEVEL_APDEF    4

#define WNI_CFG_OLBC_DETECT_TIMEOUT_STAMIN    1000
#define WNI_CFG_OLBC_DETECT_TIMEOUT_STAMAX    30000
#define WNI_CFG_OLBC_DETECT_TIMEOUT_STADEF    10000

#define WNI_CFG_OLBC_DETECT_TIMEOUT_APMIN    1000
#define WNI_CFG_OLBC_DETECT_TIMEOUT_APMAX    30000
#define WNI_CFG_OLBC_DETECT_TIMEOUT_APDEF    10000

#define WNI_CFG_PROTECTION_ENABLED_STAMIN    0
#define WNI_CFG_PROTECTION_ENABLED_STAMAX    65535
#define WNI_CFG_PROTECTION_ENABLED_STADEF    65535

#define WNI_CFG_PROTECTION_ENABLED_APMIN    0
#define WNI_CFG_PROTECTION_ENABLED_APMAX    65535
#define WNI_CFG_PROTECTION_ENABLED_APDEF    65535

#define WNI_CFG_PROTECTION_ENABLED_FROM_llA    0
#define WNI_CFG_PROTECTION_ENABLED_FROM_llB    1
#define WNI_CFG_PROTECTION_ENABLED_FROM_llG    2
#define WNI_CFG_PROTECTION_ENABLED_HT_20    3
#define WNI_CFG_PROTECTION_ENABLED_NON_GF    4
#define WNI_CFG_PROTECTION_ENABLED_LSIG_TXOP    5
#define WNI_CFG_PROTECTION_ENABLED_RIFS    6
#define WNI_CFG_PROTECTION_ENABLED_OBSS    7
#define WNI_CFG_PROTECTION_ENABLED_OLBC_FROM_llA    8
#define WNI_CFG_PROTECTION_ENABLED_OLBC_FROM_llB    9
#define WNI_CFG_PROTECTION_ENABLED_OLBC_FROM_llG    10
#define WNI_CFG_PROTECTION_ENABLED_OLBC_HT20    11
#define WNI_CFG_PROTECTION_ENABLED_OLBC_NON_GF    12
#define WNI_CFG_PROTECTION_ENABLED_OLBC_LSIG_TXOP    13
#define WNI_CFG_PROTECTION_ENABLED_OLBC_RIFS    14
#define WNI_CFG_PROTECTION_ENABLED_OLBC_OBSS    15

#define WNI_CFG_11G_PROTECTION_ALWAYS_STAMIN    0
#define WNI_CFG_11G_PROTECTION_ALWAYS_STAMAX    1
#define WNI_CFG_11G_PROTECTION_ALWAYS_STADEF    0

#define WNI_CFG_11G_PROTECTION_ALWAYS_APMIN    0
#define WNI_CFG_11G_PROTECTION_ALWAYS_APMAX    1
#define WNI_CFG_11G_PROTECTION_ALWAYS_APDEF    0

#define WNI_CFG_FORCE_POLICY_PROTECTION_STAMIN    0
#define WNI_CFG_FORCE_POLICY_PROTECTION_STAMAX    5
#define WNI_CFG_FORCE_POLICY_PROTECTION_STADEF    5

#define WNI_CFG_FORCE_POLICY_PROTECTION_APMIN    0
#define WNI_CFG_FORCE_POLICY_PROTECTION_APMAX    5
#define WNI_CFG_FORCE_POLICY_PROTECTION_APDEF    5

#define WNI_CFG_FORCE_POLICY_PROTECTION_DISABLE    0
#define WNI_CFG_FORCE_POLICY_PROTECTION_CTS    1
#define WNI_CFG_FORCE_POLICY_PROTECTION_RTS    2
#define WNI_CFG_FORCE_POLICY_PROTECTION_DUAL_CTS    3
#define WNI_CFG_FORCE_POLICY_PROTECTION_RTS_ALWAYS    4
#define WNI_CFG_FORCE_POLICY_PROTECTION_AUTO    5

#define WNI_CFG_11G_SHORT_PREAMBLE_ENABLED_STAMIN    0
#define WNI_CFG_11G_SHORT_PREAMBLE_ENABLED_STAMAX    1
#define WNI_CFG_11G_SHORT_PREAMBLE_ENABLED_STADEF    0

#define WNI_CFG_11G_SHORT_PREAMBLE_ENABLED_APMIN    0
#define WNI_CFG_11G_SHORT_PREAMBLE_ENABLED_APMAX    1
#define WNI_CFG_11G_SHORT_PREAMBLE_ENABLED_APDEF    0

#define WNI_CFG_11G_SHORT_SLOT_TIME_ENABLED_STAMIN    0
#define WNI_CFG_11G_SHORT_SLOT_TIME_ENABLED_STAMAX    1
#define WNI_CFG_11G_SHORT_SLOT_TIME_ENABLED_STADEF    1

#define WNI_CFG_11G_SHORT_SLOT_TIME_ENABLED_APMIN    0
#define WNI_CFG_11G_SHORT_SLOT_TIME_ENABLED_APMAX    1
#define WNI_CFG_11G_SHORT_SLOT_TIME_ENABLED_APDEF    1

#define WNI_CFG_CAL_PERIOD_STAMIN    2
#define WNI_CFG_CAL_PERIOD_STAMAX    10
#define WNI_CFG_CAL_PERIOD_STADEF    5

#define WNI_CFG_CAL_PERIOD_APMIN    2
#define WNI_CFG_CAL_PERIOD_APMAX    10
#define WNI_CFG_CAL_PERIOD_APDEF    5

#define WNI_CFG_STATS_PERIOD_STAMIN    1
#define WNI_CFG_STATS_PERIOD_STAMAX    10
#define WNI_CFG_STATS_PERIOD_STADEF    10

#define WNI_CFG_STATS_PERIOD_APMIN    1
#define WNI_CFG_STATS_PERIOD_APMAX    10
#define WNI_CFG_STATS_PERIOD_APDEF    10

#define WNI_CFG_CAL_CONTROL_STAMIN    0
#define WNI_CFG_CAL_CONTROL_STAMAX    1
#define WNI_CFG_CAL_CONTROL_STADEF    0

#define WNI_CFG_CAL_CONTROL_APMIN    0
#define WNI_CFG_CAL_CONTROL_APMAX    1
#define WNI_CFG_CAL_CONTROL_APDEF    0

#define WNI_CFG_CAL_CONTROL_CAL_ON    0
#define WNI_CFG_CAL_CONTROL_CAL_OFF    1

#define WNI_CFG_11G_ONLY_POLICY_STAMIN    0
#define WNI_CFG_11G_ONLY_POLICY_STAMAX    1
#define WNI_CFG_11G_ONLY_POLICY_STADEF    0

#define WNI_CFG_11G_ONLY_POLICY_APMIN    0
#define WNI_CFG_11G_ONLY_POLICY_APMAX    1
#define WNI_CFG_11G_ONLY_POLICY_APDEF    0

#define WNI_CFG_PACKET_CLASSIFICATION_STAMIN    0
#define WNI_CFG_PACKET_CLASSIFICATION_STAMAX    3
#define WNI_CFG_PACKET_CLASSIFICATION_STADEF    0

#define WNI_CFG_PACKET_CLASSIFICATION_APMIN    0
#define WNI_CFG_PACKET_CLASSIFICATION_APMAX    3
#define WNI_CFG_PACKET_CLASSIFICATION_APDEF    0

#define WNI_CFG_PACKET_CLASSIFICATION_DISABLED    0
#define WNI_CFG_PACKET_CLASSIFICATION_DSCP    1
#define WNI_CFG_PACKET_CLASSIFICATION_8021P    2
#define WNI_CFG_PACKET_CLASSIFICATION_ALL    3

#define WNI_CFG_WME_ENABLED_STAMIN    0
#define WNI_CFG_WME_ENABLED_STAMAX    1
#define WNI_CFG_WME_ENABLED_STADEF    1

#define WNI_CFG_WME_ENABLED_APMIN    0
#define WNI_CFG_WME_ENABLED_APMAX    1
#define WNI_CFG_WME_ENABLED_APDEF    1

#define WNI_CFG_ADDTS_RSP_TIMEOUT_STAMIN    0
#define WNI_CFG_ADDTS_RSP_TIMEOUT_STAMAX    65535
#define WNI_CFG_ADDTS_RSP_TIMEOUT_STADEF    1000

#define WNI_CFG_ADDTS_RSP_TIMEOUT_APMIN    0
#define WNI_CFG_ADDTS_RSP_TIMEOUT_APMAX    65535
#define WNI_CFG_ADDTS_RSP_TIMEOUT_APDEF    1000

#define WNI_CFG_MAX_SP_LENGTH_STAMIN    0
#define WNI_CFG_MAX_SP_LENGTH_STAMAX    3
#define WNI_CFG_MAX_SP_LENGTH_STADEF    0

#define WNI_CFG_MAX_SP_LENGTH_APMIN    0
#define WNI_CFG_MAX_SP_LENGTH_APMAX    3
#define WNI_CFG_MAX_SP_LENGTH_APDEF    0

#define WNI_CFG_KEEP_ALIVE_STA_LIMIT_THRESHOLD_APMIN    0
#define WNI_CFG_KEEP_ALIVE_STA_LIMIT_THRESHOLD_APMAX    32
#define WNI_CFG_KEEP_ALIVE_STA_LIMIT_THRESHOLD_APDEF    0

#define WNI_CFG_SEND_SINGLE_SSID_ALWAYS_STAMIN    0
#define WNI_CFG_SEND_SINGLE_SSID_ALWAYS_STAMAX    1
#define WNI_CFG_SEND_SINGLE_SSID_ALWAYS_STADEF    0

#define WNI_CFG_SEND_SINGLE_SSID_ALWAYS_APMIN    0
#define WNI_CFG_SEND_SINGLE_SSID_ALWAYS_APMAX    1
#define WNI_CFG_SEND_SINGLE_SSID_ALWAYS_APDEF    0

#define WNI_CFG_WSM_ENABLED_STAMIN    0
#define WNI_CFG_WSM_ENABLED_STAMAX    1
#define WNI_CFG_WSM_ENABLED_STADEF    0

#define WNI_CFG_WSM_ENABLED_APMIN    0
#define WNI_CFG_WSM_ENABLED_APMAX    1
#define WNI_CFG_WSM_ENABLED_APDEF    0

#define WNI_CFG_PROP_CAPABILITY_STAMIN    0
#define WNI_CFG_PROP_CAPABILITY_STAMAX    65535
#define WNI_CFG_PROP_CAPABILITY_STADEF    57535

#define WNI_CFG_PROP_CAPABILITY_APMIN    0
#define WNI_CFG_PROP_CAPABILITY_APMAX    65535
#define WNI_CFG_PROP_CAPABILITY_APDEF    49321

#define WNI_CFG_PROP_CAPABILITY_HCF    0
#define WNI_CFG_PROP_CAPABILITY_11EQOS    1
#define WNI_CFG_PROP_CAPABILITY_WME    2
#define WNI_CFG_PROP_CAPABILITY_WSM    3
#define WNI_CFG_PROP_CAPABILITY_EXTRATES    4
#define WNI_CFG_PROP_CAPABILITY_EXTRATE_STOP    5
#define WNI_CFG_PROP_CAPABILITY_TITAN    6
#define WNI_CFG_PROP_CAPABILITY_TAURUS    7
#define WNI_CFG_PROP_CAPABILITY_EDCAPARAMS    13
#define WNI_CFG_PROP_CAPABILITY_LOADINFO    14
#define WNI_CFG_PROP_CAPABILITY_VERSION    15
#define WNI_CFG_PROP_CAPABILITY_MAXBITOFFSET    15

#define WNI_CFG_EDCA_PROFILE_STAMIN    0
#define WNI_CFG_EDCA_PROFILE_STAMAX    255
#define WNI_CFG_EDCA_PROFILE_STADEF    1

#define WNI_CFG_EDCA_PROFILE_APMIN    0
#define WNI_CFG_EDCA_PROFILE_APMAX    255
#define WNI_CFG_EDCA_PROFILE_APDEF    1

#define WNI_CFG_EDCA_PROFILE_ANI    0
#define WNI_CFG_EDCA_PROFILE_WMM    1
#define WNI_CFG_EDCA_PROFILE_TIT_DEMO    2
#define WNI_CFG_EDCA_PROFILE_MAX    3
#define WNI_CFG_EDCA_PROFILE_ACM_IDX    0
#define WNI_CFG_EDCA_PROFILE_AIFSN_IDX    1
#define WNI_CFG_EDCA_PROFILE_CWMINA_IDX    2
#define WNI_CFG_EDCA_PROFILE_CWMAXA_IDX    4
#define WNI_CFG_EDCA_PROFILE_TXOPA_IDX    6
#define WNI_CFG_EDCA_PROFILE_CWMINB_IDX    7
#define WNI_CFG_EDCA_PROFILE_CWMAXB_IDX    9
#define WNI_CFG_EDCA_PROFILE_TXOPB_IDX    11
#define WNI_CFG_EDCA_PROFILE_CWMING_IDX    12
#define WNI_CFG_EDCA_PROFILE_CWMAXG_IDX    14
#define WNI_CFG_EDCA_PROFILE_TXOPG_IDX    16

#define WNI_CFG_RDET_FLAG_STAMIN    0
#define WNI_CFG_RDET_FLAG_STAMAX    1
#define WNI_CFG_RDET_FLAG_STADEF    0

#define WNI_CFG_RDET_FLAG_APMIN    0
#define WNI_CFG_RDET_FLAG_APMAX    1
#define WNI_CFG_RDET_FLAG_APDEF    0

#define WNI_CFG_RDET_FLAG_ENABLE    1
#define WNI_CFG_RDET_FLAG_DISABLE    0

#define WNI_CFG_LOCAL_POWER_CONSTRAINT_STAMIN    0
#define WNI_CFG_LOCAL_POWER_CONSTRAINT_STAMAX    255
#define WNI_CFG_LOCAL_POWER_CONSTRAINT_STADEF    0

#define WNI_CFG_LOCAL_POWER_CONSTRAINT_APMIN    0
#define WNI_CFG_LOCAL_POWER_CONSTRAINT_APMAX    255
#define WNI_CFG_LOCAL_POWER_CONSTRAINT_APDEF    0

#define WNI_CFG_ADMIT_POLICY_STAMIN    0
#define WNI_CFG_ADMIT_POLICY_STAMAX    2
#define WNI_CFG_ADMIT_POLICY_STADEF    0

#define WNI_CFG_ADMIT_POLICY_APMIN    0
#define WNI_CFG_ADMIT_POLICY_APMAX    2
#define WNI_CFG_ADMIT_POLICY_APDEF    0

#define WNI_CFG_ADMIT_POLICY_ADMIT_ALL    0
#define WNI_CFG_ADMIT_POLICY_REJECT_ALL    1
#define WNI_CFG_ADMIT_POLICY_BW_FACTOR    2

#define WNI_CFG_ADMIT_BWFACTOR_STAMIN    0
#define WNI_CFG_ADMIT_BWFACTOR_STAMAX    100
#define WNI_CFG_ADMIT_BWFACTOR_STADEF    20

#define WNI_CFG_ADMIT_BWFACTOR_APMIN    0
#define WNI_CFG_ADMIT_BWFACTOR_APMAX    100
#define WNI_CFG_ADMIT_BWFACTOR_APDEF    20

#define WNI_CFG_MAX_CONSECUTIVE_BACKGROUND_SCAN_FAILURE_STAMIN    0
#define WNI_CFG_MAX_CONSECUTIVE_BACKGROUND_SCAN_FAILURE_STAMAX    256
#define WNI_CFG_MAX_CONSECUTIVE_BACKGROUND_SCAN_FAILURE_STADEF    60

#define WNI_CFG_MAX_CONSECUTIVE_BACKGROUND_SCAN_FAILURE_APMIN    0
#define WNI_CFG_MAX_CONSECUTIVE_BACKGROUND_SCAN_FAILURE_APMAX    256
#define WNI_CFG_MAX_CONSECUTIVE_BACKGROUND_SCAN_FAILURE_APDEF    60

#define WNI_CFG_CHANNEL_BONDING_MODE_STAMIN    0
#define WNI_CFG_CHANNEL_BONDING_MODE_STAMAX    10
#define WNI_CFG_CHANNEL_BONDING_MODE_STADEF    0

#define WNI_CFG_CHANNEL_BONDING_MODE_APMIN    0
#define WNI_CFG_CHANNEL_BONDING_MODE_APMAX    10
#define WNI_CFG_CHANNEL_BONDING_MODE_APDEF    0

#define WNI_CFG_CHANNEL_BONDING_MODE_DISABLE    0
#define WNI_CFG_CHANNEL_BONDING_MODE_ENABLE    1
#define WNI_CFG_CHANNEL_BONDING_MODE_IF_NO_LEGACY_BSS    2
#define WNI_CFG_CHANNEL_BONDING_MODE_IF_NO_LEGACY_ALL    3
#define WNI_CFG_CHANNEL_BONDING_MODE_INTELLIGENT    4

#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_STAMIN    0
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_STAMAX    10
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_STADEF    0

#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_APMIN    0
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_APMAX    10
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_APDEF    0

#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_NONE    0
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_LOWER    1
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_HIGHER    2
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_11AC_20MHZ_LOW_40MHZ_CENTERED    3
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_11AC_20MHZ_CENTERED_40MHZ_CENTERED    4
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_11AC_20MHZ_HIGH_40MHZ_CENTERED    5
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_11AC_20MHZ_LOW_40MHZ_LOW    6
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_11AC_20MHZ_HIGH_40MHZ_LOW    7
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_11AC_20MHZ_LOW_40MHZ_HIGH    8
#define WNI_CFG_CB_SECONDARY_CHANNEL_STATE_11AC_20MHZ_HIGH_40MHZ_HIGH    9

#define WNI_CFG_DYNAMIC_THRESHOLD_ZERO_STAMIN    0
#define WNI_CFG_DYNAMIC_THRESHOLD_ZERO_STAMAX    255
#define WNI_CFG_DYNAMIC_THRESHOLD_ZERO_STADEF    2

#define WNI_CFG_DYNAMIC_THRESHOLD_ZERO_APMIN    0
#define WNI_CFG_DYNAMIC_THRESHOLD_ZERO_APMAX    255
#define WNI_CFG_DYNAMIC_THRESHOLD_ZERO_APDEF    2

#define WNI_CFG_DYNAMIC_THRESHOLD_ONE_STAMIN    0
#define WNI_CFG_DYNAMIC_THRESHOLD_ONE_STAMAX    255
#define WNI_CFG_DYNAMIC_THRESHOLD_ONE_STADEF    4

#define WNI_CFG_DYNAMIC_THRESHOLD_ONE_APMIN    0
#define WNI_CFG_DYNAMIC_THRESHOLD_ONE_APMAX    255
#define WNI_CFG_DYNAMIC_THRESHOLD_ONE_APDEF    4

#define WNI_CFG_DYNAMIC_THRESHOLD_TWO_STAMIN    0
#define WNI_CFG_DYNAMIC_THRESHOLD_TWO_STAMAX    255
#define WNI_CFG_DYNAMIC_THRESHOLD_TWO_STADEF    6

#define WNI_CFG_DYNAMIC_THRESHOLD_TWO_APMIN    0
#define WNI_CFG_DYNAMIC_THRESHOLD_TWO_APMAX    255
#define WNI_CFG_DYNAMIC_THRESHOLD_TWO_APDEF    6

#define WNI_CFG_TRIG_STA_BK_SCAN_STAMIN    0
#define WNI_CFG_TRIG_STA_BK_SCAN_STAMAX    1
#define WNI_CFG_TRIG_STA_BK_SCAN_STADEF    0

#define WNI_CFG_TRIG_STA_BK_SCAN_APMIN    0
#define WNI_CFG_TRIG_STA_BK_SCAN_APMAX    1
#define WNI_CFG_TRIG_STA_BK_SCAN_APDEF    1

#define WNI_CFG_DYNAMIC_PROFILE_SWITCHING_STAMIN    0
#define WNI_CFG_DYNAMIC_PROFILE_SWITCHING_STAMAX    255
#define WNI_CFG_DYNAMIC_PROFILE_SWITCHING_STADEF    255

#define WNI_CFG_DYNAMIC_PROFILE_SWITCHING_APMIN    0
#define WNI_CFG_DYNAMIC_PROFILE_SWITCHING_APMAX    255
#define WNI_CFG_DYNAMIC_PROFILE_SWITCHING_APDEF    1

#define WNI_CFG_DYNAMIC_PROFILE_SWITCHING_UNUSED    255

#define WNI_CFG_MIMO_ENABLED_STAMIN    0
#define WNI_CFG_MIMO_ENABLED_STAMAX    1
#define WNI_CFG_MIMO_ENABLED_STADEF    1

#define WNI_CFG_MIMO_ENABLED_APMIN    0
#define WNI_CFG_MIMO_ENABLED_APMAX    1
#define WNI_CFG_MIMO_ENABLED_APDEF    1

#define WNI_CFG_MIMO_ENABLED_ENABLE    1
#define WNI_CFG_MIMO_ENABLED_DISABLE    0

#define WNI_CFG_BLOCK_ACK_ENABLED_STAMIN    0
#define WNI_CFG_BLOCK_ACK_ENABLED_STAMAX    3
#define WNI_CFG_BLOCK_ACK_ENABLED_STADEF    0

#define WNI_CFG_BLOCK_ACK_ENABLED_APMIN    0
#define WNI_CFG_BLOCK_ACK_ENABLED_APMAX    3
#define WNI_CFG_BLOCK_ACK_ENABLED_APDEF    0

#define WNI_CFG_BLOCK_ACK_ENABLED_DELAYED    0
#define WNI_CFG_BLOCK_ACK_ENABLED_IMMEDIATE    1

#define WNI_CFG_BA_ACTIVITY_CHECK_TIMEOUT_STAMIN    0
#define WNI_CFG_BA_ACTIVITY_CHECK_TIMEOUT_STAMAX    65535
#define WNI_CFG_BA_ACTIVITY_CHECK_TIMEOUT_STADEF    1000

#define WNI_CFG_BA_ACTIVITY_CHECK_TIMEOUT_APMIN    0
#define WNI_CFG_BA_ACTIVITY_CHECK_TIMEOUT_APMAX    65535
#define WNI_CFG_BA_ACTIVITY_CHECK_TIMEOUT_APDEF    1000

#define WNI_CFG_HT_RX_STBC_STAMIN    0
#define WNI_CFG_HT_RX_STBC_STAMAX    3
#define WNI_CFG_HT_RX_STBC_STADEF    1

#define WNI_CFG_HT_RX_STBC_APMIN    0
#define WNI_CFG_HT_RX_STBC_APMAX    3
#define WNI_CFG_HT_RX_STBC_APDEF    1

#define WNI_CFG_HT_CAP_INFO_STAMIN    0
#define WNI_CFG_HT_CAP_INFO_STAMAX    65535
#define WNI_CFG_HT_CAP_INFO_STADEF    364

#define WNI_CFG_HT_CAP_INFO_APMIN    0
#define WNI_CFG_HT_CAP_INFO_APMAX    65535
#define WNI_CFG_HT_CAP_INFO_APDEF    4206

#define WNI_CFG_HT_CAP_INFO_ADVANCE_CODING    0
#define WNI_CFG_HT_CAP_INFO_SUPPORTED_CHAN_WIDTH_SET    1
#define WNI_CFG_HT_CAP_INFO_SM_POWER_SAVE    2
#define WNI_CFG_HT_CAP_INFO_GREEN_FIELD    4
#define WNI_CFG_HT_CAP_INFO_SHORT_GI_20MHZ    5
#define WNI_CFG_HT_CAP_INFO_SHORT_GI_40MHZ    6
#define WNI_CFG_HT_CAP_INFO_TX_STBC    7
#define WNI_CFG_HT_CAP_INFO_RX_STBC    8
#define WNI_CFG_HT_CAP_INFO_DELAYED_BA    10
#define WNI_CFG_HT_CAP_INFO_MAX_AMSDU_SIZE    11
#define WNI_CFG_HT_CAP_INFO_DSSS_CCK_MODE_40MHZ    12
#define WNI_CFG_HT_CAP_INFO_PSMP    13
#define WNI_CFG_HT_CAP_INFO_STBC_CONTROL_FRAME    14
#define WNI_CFG_HT_CAP_INFO_LSIG_TXOP_PROTECTION    15

#define WNI_CFG_HT_AMPDU_PARAMS_STAMIN    0
#define WNI_CFG_HT_AMPDU_PARAMS_STAMAX    255
#define WNI_CFG_HT_AMPDU_PARAMS_STADEF    0

#define WNI_CFG_HT_AMPDU_PARAMS_APMIN    0
#define WNI_CFG_HT_AMPDU_PARAMS_APMAX    255
#define WNI_CFG_HT_AMPDU_PARAMS_APDEF    2

#define WNI_CFG_HT_AMPDU_PARAMS_MAX_RX_AMPDU_FACTOR    0
#define WNI_CFG_HT_AMPDU_PARAMS_MPDU_DENSITY    2
#define WNI_CFG_HT_AMPDU_PARAMS_RESERVED    5

#define WNI_CFG_EXT_HT_CAP_INFO_STAMIN    0
#define WNI_CFG_EXT_HT_CAP_INFO_STAMAX    65535
#define WNI_CFG_EXT_HT_CAP_INFO_STADEF    1024

#define WNI_CFG_EXT_HT_CAP_INFO_APMIN    0
#define WNI_CFG_EXT_HT_CAP_INFO_APMAX    65535
#define WNI_CFG_EXT_HT_CAP_INFO_APDEF    1024

#define WNI_CFG_EXT_HT_CAP_INFO_PCO    0
#define WNI_CFG_EXT_HT_CAP_INFO_TRANSITION_TIME    1
#define WNI_CFG_EXT_HT_CAP_INFO_RESERVED1    3
#define WNI_CFG_EXT_HT_CAP_INFO_MCS_FEEDBACK    8
#define WNI_CFG_EXT_HT_CAP_INFO_HTC_SUPPORT    10
#define WNI_CFG_EXT_HT_CAP_INFO_RD_RESPONDER    11
#define WNI_CFG_EXT_HT_CAP_INFO_RESERVED2    12

#define WNI_CFG_TX_BF_CAP_STAMIN    0
#define WNI_CFG_TX_BF_CAP_STAMAX    4294967295
#define WNI_CFG_TX_BF_CAP_STADEF    0

#define WNI_CFG_TX_BF_CAP_APMIN    0
#define WNI_CFG_TX_BF_CAP_APMAX    4294967295
#define WNI_CFG_TX_BF_CAP_APDEF    0

#define WNI_CFG_AS_CAP_STAMIN    0
#define WNI_CFG_AS_CAP_STAMAX    255
#define WNI_CFG_AS_CAP_STADEF    0

#define WNI_CFG_AS_CAP_APMIN    0
#define WNI_CFG_AS_CAP_APMAX    255
#define WNI_CFG_AS_CAP_APDEF    0

#define WNI_CFG_AS_CAP_ANTENNA_SELECTION    0
#define WNI_CFG_AS_CAP_EXPLICIT_CSI_FEEDBACK_TX    1
#define WNI_CFG_AS_CAP_ANTENNA_INDICES_FEEDBACK_TX    2
#define WNI_CFG_AS_CAP_EXPLICIT_CSI_FEEDBACK    3
#define WNI_CFG_AS_CAP_ANTENNA_INDICES_FEEDBACK    4
#define WNI_CFG_AS_CAP_RX_AS    5
#define WNI_CFG_AS_CAP_TX_SOUNDING_PPDUS    6
#define WNI_CFG_AS_CAP_RESERVED    7

#define WNI_CFG_HT_INFO_FIELD1_STAMIN    0
#define WNI_CFG_HT_INFO_FIELD1_STAMAX    255
#define WNI_CFG_HT_INFO_FIELD1_STADEF    15

#define WNI_CFG_HT_INFO_FIELD1_APMIN    0
#define WNI_CFG_HT_INFO_FIELD1_APMAX    255
#define WNI_CFG_HT_INFO_FIELD1_APDEF    15

#define WNI_CFG_HT_INFO_FIELD1_SECONDARY_CHANNEL_OFFSET    0
#define WNI_CFG_HT_INFO_FIELD1_RECOMMENDED_CHANNEL_WIDTH    2
#define WNI_CFG_HT_INFO_FIELD1_RIFS_MODE    3
#define WNI_CFG_HT_INFO_FIELD1_PSMP_ACCESS_ONLY    4
#define WNI_CFG_HT_INFO_FIELD1_SERVICE_INTERVAL_GRANULARITY    5

#define WNI_CFG_HT_INFO_FIELD2_STAMIN    0
#define WNI_CFG_HT_INFO_FIELD2_STAMAX    65535
#define WNI_CFG_HT_INFO_FIELD2_STADEF    0

#define WNI_CFG_HT_INFO_FIELD2_APMIN    0
#define WNI_CFG_HT_INFO_FIELD2_APMAX    65535
#define WNI_CFG_HT_INFO_FIELD2_APDEF    0

#define WNI_CFG_HT_INFO_FIELD2_OP_MODE    0
#define WNI_CFG_HT_INFO_FIELD2_NON_GF_DEVICES_PRESENT    2
#define WNI_CFG_HT_INFO_FIELD2_RESERVED    3

#define WNI_CFG_HT_INFO_FIELD3_STAMIN    0
#define WNI_CFG_HT_INFO_FIELD3_STAMAX    65535
#define WNI_CFG_HT_INFO_FIELD3_STADEF    0

#define WNI_CFG_HT_INFO_FIELD3_APMIN    0
#define WNI_CFG_HT_INFO_FIELD3_APMAX    65535
#define WNI_CFG_HT_INFO_FIELD3_APDEF    0

#define WNI_CFG_HT_INFO_FIELD3_BASIC_STBC_MCS    0
#define WNI_CFG_HT_INFO_FIELD3_DUAL_STBC_PROTECTION    7
#define WNI_CFG_HT_INFO_FIELD3_SECONDARY_BEACON    8
#define WNI_CFG_HT_INFO_FIELD3_LSIG_TXOP_PROTECTION_FULL_SUPPORT    9
#define WNI_CFG_HT_INFO_FIELD3_PCO_ACTIVE    10
#define WNI_CFG_HT_INFO_FIELD3_PCO_PHASE    11
#define WNI_CFG_HT_INFO_FIELD3_RESERVED    12

#define WNI_CFG_GREENFIELD_CAPABILITY_STAMIN    0
#define WNI_CFG_GREENFIELD_CAPABILITY_STAMAX    1
#define WNI_CFG_GREENFIELD_CAPABILITY_STADEF    0

#define WNI_CFG_GREENFIELD_CAPABILITY_APMIN    0
#define WNI_CFG_GREENFIELD_CAPABILITY_APMAX    1
#define WNI_CFG_GREENFIELD_CAPABILITY_APDEF    0

#define WNI_CFG_GREENFIELD_CAPABILITY_ENABLE    1
#define WNI_CFG_GREENFIELD_CAPABILITY_DISABLE    0

#define WNI_CFG_VHT_MAX_MPDU_LENGTH_STAMIN    0
#define WNI_CFG_VHT_MAX_MPDU_LENGTH_STAMAX    2
#define WNI_CFG_VHT_MAX_MPDU_LENGTH_STADEF    0

#define WNI_CFG_VHT_MAX_MPDU_LENGTH_APMIN    0
#define WNI_CFG_VHT_MAX_MPDU_LENGTH_APMAX    2
#define WNI_CFG_VHT_MAX_MPDU_LENGTH_APDEF    0

#define WNI_CFG_VHT_SUPPORTED_CHAN_WIDTH_SET_STAMIN    0
#define WNI_CFG_VHT_SUPPORTED_CHAN_WIDTH_SET_STAMAX    0
#define WNI_CFG_VHT_SUPPORTED_CHAN_WIDTH_SET_STADEF    0

#define WNI_CFG_VHT_SUPPORTED_CHAN_WIDTH_SET_APMIN    0
#define WNI_CFG_VHT_SUPPORTED_CHAN_WIDTH_SET_APMAX    0
#define WNI_CFG_VHT_SUPPORTED_CHAN_WIDTH_SET_APDEF    0

#define WNI_CFG_VHT_LDPC_CODING_CAP_STAMIN    0
#define WNI_CFG_VHT_LDPC_CODING_CAP_STAMAX    1
#define WNI_CFG_VHT_LDPC_CODING_CAP_STADEF    0

#define WNI_CFG_VHT_LDPC_CODING_CAP_APMIN    0
#define WNI_CFG_VHT_LDPC_CODING_CAP_APMAX    1
#define WNI_CFG_VHT_LDPC_CODING_CAP_APDEF    0

#define WNI_CFG_VHT_SHORT_GI_80MHZ_STAMIN    0
#define WNI_CFG_VHT_SHORT_GI_80MHZ_STAMAX    1
#define WNI_CFG_VHT_SHORT_GI_80MHZ_STADEF    1

#define WNI_CFG_VHT_SHORT_GI_80MHZ_APMIN    0
#define WNI_CFG_VHT_SHORT_GI_80MHZ_APMAX    1
#define WNI_CFG_VHT_SHORT_GI_80MHZ_APDEF    1

#define WNI_CFG_VHT_SHORT_GI_160_AND_80_PLUS_80MHZ_STAMIN    0
#define WNI_CFG_VHT_SHORT_GI_160_AND_80_PLUS_80MHZ_STAMAX    1
#define WNI_CFG_VHT_SHORT_GI_160_AND_80_PLUS_80MHZ_STADEF    0

#define WNI_CFG_VHT_SHORT_GI_160_AND_80_PLUS_80MHZ_APMIN    0
#define WNI_CFG_VHT_SHORT_GI_160_AND_80_PLUS_80MHZ_APMAX    1
#define WNI_CFG_VHT_SHORT_GI_160_AND_80_PLUS_80MHZ_APDEF    0

#define WNI_CFG_VHT_TXSTBC_STAMIN    0
#define WNI_CFG_VHT_TXSTBC_STAMAX    1
#define WNI_CFG_VHT_TXSTBC_STADEF    0

#define WNI_CFG_VHT_TXSTBC_APMIN    0
#define WNI_CFG_VHT_TXSTBC_APMAX    1
#define WNI_CFG_VHT_TXSTBC_APDEF    0

#define WNI_CFG_VHT_RXSTBC_STAMIN    0
#define WNI_CFG_VHT_RXSTBC_STAMAX    1
#define WNI_CFG_VHT_RXSTBC_STADEF    1

#define WNI_CFG_VHT_RXSTBC_APMIN    0
#define WNI_CFG_VHT_RXSTBC_APMAX    1
#define WNI_CFG_VHT_RXSTBC_APDEF    1

#define WNI_CFG_VHT_SU_BEAMFORMER_CAP_STAMIN    0
#define WNI_CFG_VHT_SU_BEAMFORMER_CAP_STAMAX    1
#define WNI_CFG_VHT_SU_BEAMFORMER_CAP_STADEF    0

#define WNI_CFG_VHT_SU_BEAMFORMER_CAP_APMIN    0
#define WNI_CFG_VHT_SU_BEAMFORMER_CAP_APMAX    1
#define WNI_CFG_VHT_SU_BEAMFORMER_CAP_APDEF    0

#define WNI_CFG_VHT_SU_BEAMFORMEE_CAP_STAMIN    0
#define WNI_CFG_VHT_SU_BEAMFORMEE_CAP_STAMAX    1
#define WNI_CFG_VHT_SU_BEAMFORMEE_CAP_STADEF    0

#define WNI_CFG_VHT_SU_BEAMFORMEE_CAP_APMIN    0
#define WNI_CFG_VHT_SU_BEAMFORMEE_CAP_APMAX    1
#define WNI_CFG_VHT_SU_BEAMFORMEE_CAP_APDEF    0

#define WNI_CFG_VHT_CSN_BEAMFORMEE_ANT_SUPPORTED_STAMIN    0
#define WNI_CFG_VHT_CSN_BEAMFORMEE_ANT_SUPPORTED_STAMAX    3
#define WNI_CFG_VHT_CSN_BEAMFORMEE_ANT_SUPPORTED_STADEF    0

#define WNI_CFG_VHT_CSN_BEAMFORMEE_ANT_SUPPORTED_APMIN    0
#define WNI_CFG_VHT_CSN_BEAMFORMEE_ANT_SUPPORTED_APMAX    3
#define WNI_CFG_VHT_CSN_BEAMFORMEE_ANT_SUPPORTED_APDEF    0

#define WNI_CFG_VHT_NUM_SOUNDING_DIMENSIONS_STAMIN    0
#define WNI_CFG_VHT_NUM_SOUNDING_DIMENSIONS_STAMAX    3
#define WNI_CFG_VHT_NUM_SOUNDING_DIMENSIONS_STADEF    0

#define WNI_CFG_VHT_NUM_SOUNDING_DIMENSIONS_APMIN    0
#define WNI_CFG_VHT_NUM_SOUNDING_DIMENSIONS_APMAX    3
#define WNI_CFG_VHT_NUM_SOUNDING_DIMENSIONS_APDEF    0

#define WNI_CFG_VHT_MU_BEAMFORMER_CAP_STAMIN    0
#define WNI_CFG_VHT_MU_BEAMFORMER_CAP_STAMAX    1
#define WNI_CFG_VHT_MU_BEAMFORMER_CAP_STADEF    0

#define WNI_CFG_VHT_MU_BEAMFORMER_CAP_APMIN    0
#define WNI_CFG_VHT_MU_BEAMFORMER_CAP_APMAX    1
#define WNI_CFG_VHT_MU_BEAMFORMER_CAP_APDEF    0

#define WNI_CFG_VHT_MU_BEAMFORMEE_CAP_STAMIN    0
#define WNI_CFG_VHT_MU_BEAMFORMEE_CAP_STAMAX    1
#define WNI_CFG_VHT_MU_BEAMFORMEE_CAP_STADEF    0

#define WNI_CFG_VHT_MU_BEAMFORMEE_CAP_APMIN    0
#define WNI_CFG_VHT_MU_BEAMFORMEE_CAP_APMAX    1
#define WNI_CFG_VHT_MU_BEAMFORMEE_CAP_APDEF    0

#define WNI_CFG_VHT_TXOP_PS_STAMIN    0
#define WNI_CFG_VHT_TXOP_PS_STAMAX    1
#define WNI_CFG_VHT_TXOP_PS_STADEF    0

#define WNI_CFG_VHT_TXOP_PS_APMIN    0
#define WNI_CFG_VHT_TXOP_PS_APMAX    1
#define WNI_CFG_VHT_TXOP_PS_APDEF    0

#define WNI_CFG_VHT_HTC_VHTC_CAP_STAMIN    0
#define WNI_CFG_VHT_HTC_VHTC_CAP_STAMAX    1
#define WNI_CFG_VHT_HTC_VHTC_CAP_STADEF    0

#define WNI_CFG_VHT_HTC_VHTC_CAP_APMIN    0
#define WNI_CFG_VHT_HTC_VHTC_CAP_APMAX    1
#define WNI_CFG_VHT_HTC_VHTC_CAP_APDEF    0

#define WNI_CFG_VHT_AMPDU_LEN_EXPONENT_STAMIN    0
#define WNI_CFG_VHT_AMPDU_LEN_EXPONENT_STAMAX    7
#define WNI_CFG_VHT_AMPDU_LEN_EXPONENT_STADEF    3

#define WNI_CFG_VHT_AMPDU_LEN_EXPONENT_APMIN    0
#define WNI_CFG_VHT_AMPDU_LEN_EXPONENT_APMAX    7
#define WNI_CFG_VHT_AMPDU_LEN_EXPONENT_APDEF    3

#define WNI_CFG_VHT_LINK_ADAPTATION_CAP_STAMIN    0
#define WNI_CFG_VHT_LINK_ADAPTATION_CAP_STAMAX    3
#define WNI_CFG_VHT_LINK_ADAPTATION_CAP_STADEF    0

#define WNI_CFG_VHT_LINK_ADAPTATION_CAP_APMIN    0
#define WNI_CFG_VHT_LINK_ADAPTATION_CAP_APMAX    3
#define WNI_CFG_VHT_LINK_ADAPTATION_CAP_APDEF    0

#define WNI_CFG_VHT_RX_ANT_PATTERN_STAMIN    0
#define WNI_CFG_VHT_RX_ANT_PATTERN_STAMAX    1
#define WNI_CFG_VHT_RX_ANT_PATTERN_STADEF    1

#define WNI_CFG_VHT_RX_ANT_PATTERN_APMIN    0
#define WNI_CFG_VHT_RX_ANT_PATTERN_APMAX    1
#define WNI_CFG_VHT_RX_ANT_PATTERN_APDEF    1

#define WNI_CFG_VHT_TX_ANT_PATTERN_STAMIN    0
#define WNI_CFG_VHT_TX_ANT_PATTERN_STAMAX    1
#define WNI_CFG_VHT_TX_ANT_PATTERN_STADEF    1

#define WNI_CFG_VHT_TX_ANT_PATTERN_APMIN    0
#define WNI_CFG_VHT_TX_ANT_PATTERN_APMAX    1
#define WNI_CFG_VHT_TX_ANT_PATTERN_APDEF    1

#define WNI_CFG_VHT_RX_MCS_MAP_STAMIN    0
#define WNI_CFG_VHT_RX_MCS_MAP_STAMAX    65535
#define WNI_CFG_VHT_RX_MCS_MAP_STADEF    65534

#define WNI_CFG_VHT_RX_MCS_MAP_APMIN    0
#define WNI_CFG_VHT_RX_MCS_MAP_APMAX    65535
#define WNI_CFG_VHT_RX_MCS_MAP_APDEF    65534

#define WNI_CFG_VHT_TX_MCS_MAP_STAMIN    0
#define WNI_CFG_VHT_TX_MCS_MAP_STAMAX    65535
#define WNI_CFG_VHT_TX_MCS_MAP_STADEF    65534

#define WNI_CFG_VHT_TX_MCS_MAP_APMIN    0
#define WNI_CFG_VHT_TX_MCS_MAP_APMAX    65535
#define WNI_CFG_VHT_TX_MCS_MAP_APDEF    65534

#define WNI_CFG_VHT_RX_HIGHEST_SUPPORTED_DATA_RATE_STAMIN    1
#define WNI_CFG_VHT_RX_HIGHEST_SUPPORTED_DATA_RATE_STAMAX    434
#define WNI_CFG_VHT_RX_HIGHEST_SUPPORTED_DATA_RATE_STADEF    434

#define WNI_CFG_VHT_RX_HIGHEST_SUPPORTED_DATA_RATE_APMIN    1
#define WNI_CFG_VHT_RX_HIGHEST_SUPPORTED_DATA_RATE_APMAX    434
#define WNI_CFG_VHT_RX_HIGHEST_SUPPORTED_DATA_RATE_APDEF    434

#define WNI_CFG_VHT_TX_HIGHEST_SUPPORTED_DATA_RATE_STAMIN    1
#define WNI_CFG_VHT_TX_HIGHEST_SUPPORTED_DATA_RATE_STAMAX    434
#define WNI_CFG_VHT_TX_HIGHEST_SUPPORTED_DATA_RATE_STADEF    434

#define WNI_CFG_VHT_TX_HIGHEST_SUPPORTED_DATA_RATE_APMIN    1
#define WNI_CFG_VHT_TX_HIGHEST_SUPPORTED_DATA_RATE_APMAX    434
#define WNI_CFG_VHT_TX_HIGHEST_SUPPORTED_DATA_RATE_APDEF    434

#define WNI_CFG_VHT_CHANNEL_WIDTH_STAMIN    0
#define WNI_CFG_VHT_CHANNEL_WIDTH_STAMAX    3
#define WNI_CFG_VHT_CHANNEL_WIDTH_STADEF    0

#define WNI_CFG_VHT_CHANNEL_WIDTH_APMIN    0
#define WNI_CFG_VHT_CHANNEL_WIDTH_APMAX    3
#define WNI_CFG_VHT_CHANNEL_WIDTH_APDEF    0

#define WNI_CFG_VHT_CHANNEL_WIDTH_20_40MHZ    0
#define WNI_CFG_VHT_CHANNEL_WIDTH_80MHZ    1
#define WNI_CFG_VHT_CHANNEL_WIDTH_160MHZ    2
#define WNI_CFG_VHT_CHANNEL_WIDTH_80_PLUS_80MHZ    3

#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT1_STAMIN    0
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT1_STAMAX    256
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT1_STADEF    0

#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT1_APMIN    0
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT1_APMAX    256
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT1_APDEF    0

#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT2_STAMIN    0
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT2_STAMAX    0
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT2_STADEF    0

#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT2_APMIN    0
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT2_APMAX    0
#define WNI_CFG_VHT_CHANNEL_CENTER_FREQ_SEGMENT2_APDEF    0

#define WNI_CFG_VHT_BASIC_MCS_SET_STAMIN    0
#define WNI_CFG_VHT_BASIC_MCS_SET_STAMAX    65535
#define WNI_CFG_VHT_BASIC_MCS_SET_STADEF    65534

#define WNI_CFG_VHT_BASIC_MCS_SET_APMIN    0
#define WNI_CFG_VHT_BASIC_MCS_SET_APMAX    65535
#define WNI_CFG_VHT_BASIC_MCS_SET_APDEF    65534

#define WNI_CFG_VHT_MU_MIMO_CAP_STA_COUNT_STAMIN    0
#define WNI_CFG_VHT_MU_MIMO_CAP_STA_COUNT_STAMAX    4
#define WNI_CFG_VHT_MU_MIMO_CAP_STA_COUNT_STADEF    0

#define WNI_CFG_VHT_MU_MIMO_CAP_STA_COUNT_APMIN    0
#define WNI_CFG_VHT_MU_MIMO_CAP_STA_COUNT_APMAX    4
#define WNI_CFG_VHT_MU_MIMO_CAP_STA_COUNT_APDEF    0

#define WNI_CFG_VHT_SS_UNDER_UTIL_STAMIN    0
#define WNI_CFG_VHT_SS_UNDER_UTIL_STAMAX    0
#define WNI_CFG_VHT_SS_UNDER_UTIL_STADEF    0

#define WNI_CFG_VHT_SS_UNDER_UTIL_APMIN    0
#define WNI_CFG_VHT_SS_UNDER_UTIL_APMAX    0
#define WNI_CFG_VHT_SS_UNDER_UTIL_APDEF    0

#define WNI_CFG_VHT_40MHZ_UTILIZATION_STAMIN    0
#define WNI_CFG_VHT_40MHZ_UTILIZATION_STAMAX    0
#define WNI_CFG_VHT_40MHZ_UTILIZATION_STADEF    0

#define WNI_CFG_VHT_40MHZ_UTILIZATION_APMIN    0
#define WNI_CFG_VHT_40MHZ_UTILIZATION_APMAX    0
#define WNI_CFG_VHT_40MHZ_UTILIZATION_APDEF    0

#define WNI_CFG_VHT_80MHZ_UTILIZATION_STAMIN    0
#define WNI_CFG_VHT_80MHZ_UTILIZATION_STAMAX    0
#define WNI_CFG_VHT_80MHZ_UTILIZATION_STADEF    0

#define WNI_CFG_VHT_80MHZ_UTILIZATION_APMIN    0
#define WNI_CFG_VHT_80MHZ_UTILIZATION_APMAX    0
#define WNI_CFG_VHT_80MHZ_UTILIZATION_APDEF    0

#define WNI_CFG_VHT_160MHZ_UTILIZATION_STAMIN    0
#define WNI_CFG_VHT_160MHZ_UTILIZATION_STAMAX    0
#define WNI_CFG_VHT_160MHZ_UTILIZATION_STADEF    0

#define WNI_CFG_VHT_160MHZ_UTILIZATION_APMIN    0
#define WNI_CFG_VHT_160MHZ_UTILIZATION_APMAX    0
#define WNI_CFG_VHT_160MHZ_UTILIZATION_APDEF    0

#define WNI_CFG_MAX_AMSDU_LENGTH_STAMIN    0
#define WNI_CFG_MAX_AMSDU_LENGTH_STAMAX    1
#define WNI_CFG_MAX_AMSDU_LENGTH_STADEF    0

#define WNI_CFG_MAX_AMSDU_LENGTH_APMIN    0
#define WNI_CFG_MAX_AMSDU_LENGTH_APMAX    1
#define WNI_CFG_MAX_AMSDU_LENGTH_APDEF    0

#define WNI_CFG_MAX_AMSDU_LENGTH_SHORT_3839_BYTES    0
#define WNI_CFG_MAX_AMSDU_LENGTH_LONG_7935__BYTES    1

#define WNI_CFG_MPDU_DENSITY_STAMIN    0
#define WNI_CFG_MPDU_DENSITY_STAMAX    7
#define WNI_CFG_MPDU_DENSITY_STADEF    0

#define WNI_CFG_MPDU_DENSITY_APMIN    0
#define WNI_CFG_MPDU_DENSITY_APMAX    7
#define WNI_CFG_MPDU_DENSITY_APDEF    0

#define WNI_CFG_NUM_BUFF_ADVERT_STAMIN    0
#define WNI_CFG_NUM_BUFF_ADVERT_STAMAX    128
#define WNI_CFG_NUM_BUFF_ADVERT_STADEF    64

#define WNI_CFG_NUM_BUFF_ADVERT_APMIN    0
#define WNI_CFG_NUM_BUFF_ADVERT_APMAX    128
#define WNI_CFG_NUM_BUFF_ADVERT_APDEF    64

#define WNI_CFG_MAX_RX_AMPDU_FACTOR_STAMIN    0
#define WNI_CFG_MAX_RX_AMPDU_FACTOR_STAMAX    3
#define WNI_CFG_MAX_RX_AMPDU_FACTOR_STADEF    3

#define WNI_CFG_MAX_RX_AMPDU_FACTOR_APMIN    0
#define WNI_CFG_MAX_RX_AMPDU_FACTOR_APMAX    3
#define WNI_CFG_MAX_RX_AMPDU_FACTOR_APDEF    3

#define WNI_CFG_SHORT_GI_20MHZ_STAMIN    0
#define WNI_CFG_SHORT_GI_20MHZ_STAMAX    1
#define WNI_CFG_SHORT_GI_20MHZ_STADEF    1

#define WNI_CFG_SHORT_GI_20MHZ_APMIN    0
#define WNI_CFG_SHORT_GI_20MHZ_APMAX    1
#define WNI_CFG_SHORT_GI_20MHZ_APDEF    1

#define WNI_CFG_SHORT_GI_20MHZ_ENABLE    1
#define WNI_CFG_SHORT_GI_20MHZ_DISABLE    0

#define WNI_CFG_SHORT_GI_40MHZ_STAMIN    0
#define WNI_CFG_SHORT_GI_40MHZ_STAMAX    1
#define WNI_CFG_SHORT_GI_40MHZ_STADEF    0

#define WNI_CFG_SHORT_GI_40MHZ_APMIN    0
#define WNI_CFG_SHORT_GI_40MHZ_APMAX    1
#define WNI_CFG_SHORT_GI_40MHZ_APDEF    1

#define WNI_CFG_SHORT_GI_40MHZ_ENABLE    1
#define WNI_CFG_SHORT_GI_40MHZ_DISABLE    0

#define WNI_CFG_RIFS_ENABLED_STAMIN    0
#define WNI_CFG_RIFS_ENABLED_STAMAX    1
#define WNI_CFG_RIFS_ENABLED_STADEF    1

#define WNI_CFG_RIFS_ENABLED_APMIN    0
#define WNI_CFG_RIFS_ENABLED_APMAX    1
#define WNI_CFG_RIFS_ENABLED_APDEF    1

#define WNI_CFG_RIFS_ENABLED_ENABLE    1
#define WNI_CFG_RIFS_ENABLED_DISABLE    0

#define WNI_CFG_MAX_PS_POLL_STAMIN    0
#define WNI_CFG_MAX_PS_POLL_STAMAX    255
#define WNI_CFG_MAX_PS_POLL_STADEF    0

#define WNI_CFG_NUM_BEACON_PER_RSSI_AVERAGE_STAMIN    1
#define WNI_CFG_NUM_BEACON_PER_RSSI_AVERAGE_STAMAX    20
#define WNI_CFG_NUM_BEACON_PER_RSSI_AVERAGE_STADEF    20

#define WNI_CFG_RSSI_FILTER_PERIOD_STAMIN    0
#define WNI_CFG_RSSI_FILTER_PERIOD_STAMAX    255
#define WNI_CFG_RSSI_FILTER_PERIOD_STADEF    5

#define WNI_CFG_MIN_RSSI_THRESHOLD_STAMIN    0
#define WNI_CFG_MIN_RSSI_THRESHOLD_STAMAX    10
#define WNI_CFG_MIN_RSSI_THRESHOLD_STADEF    10

#define WNI_CFG_NTH_BEACON_FILTER_STAMIN    0
#define WNI_CFG_NTH_BEACON_FILTER_STAMAX    255
#define WNI_CFG_NTH_BEACON_FILTER_STADEF    10

#define WNI_CFG_BROADCAST_FRAME_FILTER_ENABLE_STAMIN    0
#define WNI_CFG_BROADCAST_FRAME_FILTER_ENABLE_STAMAX    1
#define WNI_CFG_BROADCAST_FRAME_FILTER_ENABLE_STADEF    0

#define WNI_CFG_SCAN_IN_POWERSAVE_STAMIN    0
#define WNI_CFG_SCAN_IN_POWERSAVE_STAMAX    1
#define WNI_CFG_SCAN_IN_POWERSAVE_STADEF    1

#define WNI_CFG_SCAN_IN_POWERSAVE_APMIN    0
#define WNI_CFG_SCAN_IN_POWERSAVE_APMAX    1
#define WNI_CFG_SCAN_IN_POWERSAVE_APDEF    1

#define WNI_CFG_IGNORE_DTIM_STAMIN    0
#define WNI_CFG_IGNORE_DTIM_STAMAX    1
#define WNI_CFG_IGNORE_DTIM_STADEF    0

#define WNI_CFG_IGNORE_DTIM_APMIN    0
#define WNI_CFG_IGNORE_DTIM_APMAX    1
#define WNI_CFG_IGNORE_DTIM_APDEF    0

#define WNI_CFG_WOWLAN_UCAST_PATTERN_FILTER_ENABLE_STAMIN    0
#define WNI_CFG_WOWLAN_UCAST_PATTERN_FILTER_ENABLE_STAMAX    1
#define WNI_CFG_WOWLAN_UCAST_PATTERN_FILTER_ENABLE_STADEF    1

#define WNI_CFG_WOWLAN_CHANNEL_SWITCH_ENABLE_STAMIN    0
#define WNI_CFG_WOWLAN_CHANNEL_SWITCH_ENABLE_STAMAX    1
#define WNI_CFG_WOWLAN_CHANNEL_SWITCH_ENABLE_STADEF    1

#define WNI_CFG_WOWLAN_DEAUTH_ENABLE_STAMIN    0
#define WNI_CFG_WOWLAN_DEAUTH_ENABLE_STAMAX    1
#define WNI_CFG_WOWLAN_DEAUTH_ENABLE_STADEF    1

#define WNI_CFG_WOWLAN_DISASSOC_ENABLE_STAMIN    0
#define WNI_CFG_WOWLAN_DISASSOC_ENABLE_STAMAX    1
#define WNI_CFG_WOWLAN_DISASSOC_ENABLE_STADEF    1

#define WNI_CFG_WOWLAN_MAX_MISSED_BEACON_STAMIN    0
#define WNI_CFG_WOWLAN_MAX_MISSED_BEACON_STAMAX    65535
#define WNI_CFG_WOWLAN_MAX_MISSED_BEACON_STADEF    40

#define WNI_CFG_WOWLAN_MAX_SLEEP_PERIOD_STAMIN    0
#define WNI_CFG_WOWLAN_MAX_SLEEP_PERIOD_STAMAX    65535
#define WNI_CFG_WOWLAN_MAX_SLEEP_PERIOD_STADEF    65535

#define WNI_CFG_BA_TIMEOUT_STAMIN    0
#define WNI_CFG_BA_TIMEOUT_STAMAX    65535
#define WNI_CFG_BA_TIMEOUT_STADEF    0

#define WNI_CFG_BA_TIMEOUT_APMIN    0
#define WNI_CFG_BA_TIMEOUT_APMAX    65535
#define WNI_CFG_BA_TIMEOUT_APDEF    0

#define WNI_CFG_BA_THRESHOLD_HIGH_STAMIN    0
#define WNI_CFG_BA_THRESHOLD_HIGH_STAMAX    65535
#define WNI_CFG_BA_THRESHOLD_HIGH_STADEF    128

#define WNI_CFG_BA_THRESHOLD_HIGH_APMIN    0
#define WNI_CFG_BA_THRESHOLD_HIGH_APMAX    65535
#define WNI_CFG_BA_THRESHOLD_HIGH_APDEF    128

#define WNI_CFG_MAX_BA_BUFFERS_STAMIN    0
#define WNI_CFG_MAX_BA_BUFFERS_STAMAX    2560
#define WNI_CFG_MAX_BA_BUFFERS_STADEF    2560

#define WNI_CFG_MAX_BA_BUFFERS_APMIN    0
#define WNI_CFG_MAX_BA_BUFFERS_APMAX    2560
#define WNI_CFG_MAX_BA_BUFFERS_APDEF    2560

#define WNI_CFG_MAX_BA_SESSIONS_STAMIN    0
#define WNI_CFG_MAX_BA_SESSIONS_STAMAX    64
#define WNI_CFG_MAX_BA_SESSIONS_STADEF    40

#define WNI_CFG_MAX_BA_SESSIONS_APMIN    0
#define WNI_CFG_MAX_BA_SESSIONS_APMAX    64
#define WNI_CFG_MAX_BA_SESSIONS_APDEF    40

#define WNI_CFG_BA_AUTO_SETUP_STAMIN    0
#define WNI_CFG_BA_AUTO_SETUP_STAMAX    1
#define WNI_CFG_BA_AUTO_SETUP_STADEF    1

#define WNI_CFG_BA_AUTO_SETUP_APMIN    0
#define WNI_CFG_BA_AUTO_SETUP_APMAX    1
#define WNI_CFG_BA_AUTO_SETUP_APDEF    1

#define WNI_CFG_BA_AUTO_SETUP_ENABLE    1
#define WNI_CFG_BA_AUTO_SETUP_DISABLE    0

#define WNI_CFG_ADDBA_REQ_DECLINE_STAMIN    0
#define WNI_CFG_ADDBA_REQ_DECLINE_STAMAX    255
#define WNI_CFG_ADDBA_REQ_DECLINE_STADEF    0

#define WNI_CFG_ADDBA_REQ_DECLINE_APMIN    0
#define WNI_CFG_ADDBA_REQ_DECLINE_APMAX    255
#define WNI_CFG_ADDBA_REQ_DECLINE_APDEF    0

#define WNI_CFG_DEL_ALL_RX_BA_SESSIONS_2_4_G_BTC_STAMIN    0
#define WNI_CFG_DEL_ALL_RX_BA_SESSIONS_2_4_G_BTC_STAMAX    1
#define WNI_CFG_DEL_ALL_RX_BA_SESSIONS_2_4_G_BTC_STADEF    0

#define WNI_CFG_DEL_ALL_RX_BA_SESSIONS_2_4_G_BTC_APMIN    0
#define WNI_CFG_DEL_ALL_RX_BA_SESSIONS_2_4_G_BTC_APMAX    1
#define WNI_CFG_DEL_ALL_RX_BA_SESSIONS_2_4_G_BTC_APDEF    0

#define WNI_CFG_MAX_MEDIUM_TIME_STAMIN    0
#define WNI_CFG_MAX_MEDIUM_TIME_STAMAX    65535
#define WNI_CFG_MAX_MEDIUM_TIME_STADEF    2048

#define WNI_CFG_MAX_MEDIUM_TIME_APMIN    0
#define WNI_CFG_MAX_MEDIUM_TIME_APMAX    65535
#define WNI_CFG_MAX_MEDIUM_TIME_APDEF    2048

#define WNI_CFG_MAX_MPDUS_IN_AMPDU_STAMIN    0
#define WNI_CFG_MAX_MPDUS_IN_AMPDU_STAMAX    65535
#define WNI_CFG_MAX_MPDUS_IN_AMPDU_STADEF    64

#define WNI_CFG_MAX_MPDUS_IN_AMPDU_APMIN    0
#define WNI_CFG_MAX_MPDUS_IN_AMPDU_APMAX    65535
#define WNI_CFG_MAX_MPDUS_IN_AMPDU_APDEF    64

#define WNI_CFG_IBSS_AUTO_BSSID_STAMIN    0
#define WNI_CFG_IBSS_AUTO_BSSID_STAMAX    1
#define WNI_CFG_IBSS_AUTO_BSSID_STADEF    1

#define WNI_CFG_PROBE_REQ_ADDNIE_FLAG_STAMIN    0
#define WNI_CFG_PROBE_REQ_ADDNIE_FLAG_STAMAX    1
#define WNI_CFG_PROBE_REQ_ADDNIE_FLAG_STADEF    0

#define WNI_CFG_PROBE_REQ_ADDNIE_FLAG_APMIN    0
#define WNI_CFG_PROBE_REQ_ADDNIE_FLAG_APMAX    1
#define WNI_CFG_PROBE_REQ_ADDNIE_FLAG_APDEF    0

#define WNI_CFG_PROBE_RSP_ADDNIE_FLAG_STAMIN    0
#define WNI_CFG_PROBE_RSP_ADDNIE_FLAG_STAMAX    1
#define WNI_CFG_PROBE_RSP_ADDNIE_FLAG_STADEF    0

#define WNI_CFG_PROBE_RSP_ADDNIE_FLAG_APMIN    0
#define WNI_CFG_PROBE_RSP_ADDNIE_FLAG_APMAX    1
#define WNI_CFG_PROBE_RSP_ADDNIE_FLAG_APDEF    0

#define WNI_CFG_ASSOC_RSP_ADDNIE_FLAG_STAMIN    0
#define WNI_CFG_ASSOC_RSP_ADDNIE_FLAG_STAMAX    1
#define WNI_CFG_ASSOC_RSP_ADDNIE_FLAG_STADEF    0

#define WNI_CFG_ASSOC_RSP_ADDNIE_FLAG_APMIN    0
#define WNI_CFG_ASSOC_RSP_ADDNIE_FLAG_APMAX    1
#define WNI_CFG_ASSOC_RSP_ADDNIE_FLAG_APDEF    0

#define WNI_CFG_PROBE_REQ_ADDNP2PIE_FLAG_STAMIN    0
#define WNI_CFG_PROBE_REQ_ADDNP2PIE_FLAG_STAMAX    1
#define WNI_CFG_PROBE_REQ_ADDNP2PIE_FLAG_STADEF    0

#define WNI_CFG_PROBE_REQ_ADDNP2PIE_FLAG_APMIN    0
#define WNI_CFG_PROBE_REQ_ADDNP2PIE_FLAG_APMAX    1
#define WNI_CFG_PROBE_REQ_ADDNP2PIE_FLAG_APDEF    0

#define WNI_CFG_PROBE_RSP_BCN_ADDNIE_FLAG_STAMIN    0
#define WNI_CFG_PROBE_RSP_BCN_ADDNIE_FLAG_STAMAX    1
#define WNI_CFG_PROBE_RSP_BCN_ADDNIE_FLAG_STADEF    0

#define WNI_CFG_PROBE_RSP_BCN_ADDNIE_FLAG_APMIN    0
#define WNI_CFG_PROBE_RSP_BCN_ADDNIE_FLAG_APMAX    1
#define WNI_CFG_PROBE_RSP_BCN_ADDNIE_FLAG_APDEF    0

#define WNI_CFG_WPS_ENABLE_STAMIN    0
#define WNI_CFG_WPS_ENABLE_STAMAX    255
#define WNI_CFG_WPS_ENABLE_STADEF    0

#define WNI_CFG_WPS_ENABLE_APMIN    0
#define WNI_CFG_WPS_ENABLE_APMAX    255
#define WNI_CFG_WPS_ENABLE_APDEF    0

#define WNI_CFG_WPS_ENABLE_AP    1
#define WNI_CFG_WPS_ENABLE_STA    2

#define WNI_CFG_WPS_STATE_STAMIN    0
#define WNI_CFG_WPS_STATE_STAMAX    255
#define WNI_CFG_WPS_STATE_STADEF    1

#define WNI_CFG_WPS_STATE_APMIN    0
#define WNI_CFG_WPS_STATE_APMAX    255
#define WNI_CFG_WPS_STATE_APDEF    1

#define WNI_CFG_WPS_PROBE_REQ_FLAG_STAMIN    0
#define WNI_CFG_WPS_PROBE_REQ_FLAG_STAMAX    1
#define WNI_CFG_WPS_PROBE_REQ_FLAG_STADEF    0

#define WNI_CFG_WPS_PROBE_REQ_FLAG_APMIN    0
#define WNI_CFG_WPS_PROBE_REQ_FLAG_APMAX    1
#define WNI_CFG_WPS_PROBE_REQ_FLAG_APDEF    0

#define WNI_CFG_WPS_VERSION_STAMIN    0
#define WNI_CFG_WPS_VERSION_STAMAX    255
#define WNI_CFG_WPS_VERSION_STADEF    16

#define WNI_CFG_WPS_VERSION_APMIN    0
#define WNI_CFG_WPS_VERSION_APMAX    255
#define WNI_CFG_WPS_VERSION_APDEF    16

#define WNI_CFG_WPS_REQUEST_TYPE_STAMIN    0
#define WNI_CFG_WPS_REQUEST_TYPE_STAMAX    255
#define WNI_CFG_WPS_REQUEST_TYPE_STADEF    0

#define WNI_CFG_WPS_REQUEST_TYPE_APMIN    0
#define WNI_CFG_WPS_REQUEST_TYPE_APMAX    255
#define WNI_CFG_WPS_REQUEST_TYPE_APDEF    3

#define WNI_CFG_WPS_CFG_METHOD_STAMIN    0
#define WNI_CFG_WPS_CFG_METHOD_STAMAX    4294967295
#define WNI_CFG_WPS_CFG_METHOD_STADEF    8

#define WNI_CFG_WPS_CFG_METHOD_APMIN    0
#define WNI_CFG_WPS_CFG_METHOD_APMAX    4294967295
#define WNI_CFG_WPS_CFG_METHOD_APDEF    25952654

#define WNI_CFG_WPS_PRIMARY_DEVICE_CATEGORY_STAMIN    0
#define WNI_CFG_WPS_PRIMARY_DEVICE_CATEGORY_STAMAX    65535
#define WNI_CFG_WPS_PRIMARY_DEVICE_CATEGORY_STADEF    1

#define WNI_CFG_WPS_PRIMARY_DEVICE_CATEGORY_APMIN    0
#define WNI_CFG_WPS_PRIMARY_DEVICE_CATEGORY_APMAX    65535
#define WNI_CFG_WPS_PRIMARY_DEVICE_CATEGORY_APDEF    6

#define WNI_CFG_WPS_PIMARY_DEVICE_OUI_STAMIN    0
#define WNI_CFG_WPS_PIMARY_DEVICE_OUI_STAMAX    4294967295
#define WNI_CFG_WPS_PIMARY_DEVICE_OUI_STADEF    5304836

#define WNI_CFG_WPS_PIMARY_DEVICE_OUI_APMIN    0
#define WNI_CFG_WPS_PIMARY_DEVICE_OUI_APMAX    4294967295
#define WNI_CFG_WPS_PIMARY_DEVICE_OUI_APDEF    5304836

#define WNI_CFG_WPS_DEVICE_SUB_CATEGORY_STAMIN    0
#define WNI_CFG_WPS_DEVICE_SUB_CATEGORY_STAMAX    65535
#define WNI_CFG_WPS_DEVICE_SUB_CATEGORY_STADEF    1

#define WNI_CFG_WPS_DEVICE_SUB_CATEGORY_APMIN    0
#define WNI_CFG_WPS_DEVICE_SUB_CATEGORY_APMAX    65535
#define WNI_CFG_WPS_DEVICE_SUB_CATEGORY_APDEF    1

#define WNI_CFG_WPS_ASSOCIATION_STATE_STAMIN    0
#define WNI_CFG_WPS_ASSOCIATION_STATE_STAMAX    65535
#define WNI_CFG_WPS_ASSOCIATION_STATE_STADEF    0

#define WNI_CFG_WPS_ASSOCIATION_STATE_APMIN    0
#define WNI_CFG_WPS_ASSOCIATION_STATE_APMAX    65535
#define WNI_CFG_WPS_ASSOCIATION_STATE_APDEF    0

#define WNI_CFG_WPS_CONFIGURATION_ERROR_STAMIN    0
#define WNI_CFG_WPS_CONFIGURATION_ERROR_STAMAX    65535
#define WNI_CFG_WPS_CONFIGURATION_ERROR_STADEF    0

#define WNI_CFG_WPS_CONFIGURATION_ERROR_APMIN    0
#define WNI_CFG_WPS_CONFIGURATION_ERROR_APMAX    65535
#define WNI_CFG_WPS_CONFIGURATION_ERROR_APDEF    0

#define WNI_CFG_WPS_DEVICE_PASSWORD_ID_STAMIN    0
#define WNI_CFG_WPS_DEVICE_PASSWORD_ID_STAMAX    4294967295
#define WNI_CFG_WPS_DEVICE_PASSWORD_ID_STADEF    0

#define WNI_CFG_WPS_DEVICE_PASSWORD_ID_APMIN    0
#define WNI_CFG_WPS_DEVICE_PASSWORD_ID_APMAX    4294967295
#define WNI_CFG_WPS_DEVICE_PASSWORD_ID_APDEF    0

#define WNI_CFG_WPS_ASSOC_METHOD_STAMIN    0
#define WNI_CFG_WPS_ASSOC_METHOD_STAMAX    65535
#define WNI_CFG_WPS_ASSOC_METHOD_STADEF    0

#define WNI_CFG_WPS_ASSOC_METHOD_APMIN    0
#define WNI_CFG_WPS_ASSOC_METHOD_APMAX    65535
#define WNI_CFG_WPS_ASSOC_METHOD_APDEF    0

#define WNI_CFG_LOW_GAIN_OVERRIDE_STAMIN    0
#define WNI_CFG_LOW_GAIN_OVERRIDE_STAMAX    1
#define WNI_CFG_LOW_GAIN_OVERRIDE_STADEF    0

#define WNI_CFG_LOW_GAIN_OVERRIDE_APMIN    0
#define WNI_CFG_LOW_GAIN_OVERRIDE_APMAX    1
#define WNI_CFG_LOW_GAIN_OVERRIDE_APDEF    0

#define WNI_CFG_ENABLE_PHY_AGC_LISTEN_MODE_STAMIN    0
#define WNI_CFG_ENABLE_PHY_AGC_LISTEN_MODE_STAMAX    128
#define WNI_CFG_ENABLE_PHY_AGC_LISTEN_MODE_STADEF    128

#define WNI_CFG_ENABLE_PHY_AGC_LISTEN_MODE_APMIN    0
#define WNI_CFG_ENABLE_PHY_AGC_LISTEN_MODE_APMAX    128
#define WNI_CFG_ENABLE_PHY_AGC_LISTEN_MODE_APDEF    128

#define WNI_CFG_RPE_POLLING_THRESHOLD_STAMIN    0
#define WNI_CFG_RPE_POLLING_THRESHOLD_STAMAX    65535
#define WNI_CFG_RPE_POLLING_THRESHOLD_STADEF    10

#define WNI_CFG_RPE_POLLING_THRESHOLD_APMIN    0
#define WNI_CFG_RPE_POLLING_THRESHOLD_APMAX    65535
#define WNI_CFG_RPE_POLLING_THRESHOLD_APDEF    10

#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC0_REG_STAMIN    0
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC0_REG_STAMAX    65535
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC0_REG_STADEF    30

#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC0_REG_APMIN    0
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC0_REG_APMAX    65535
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC0_REG_APDEF    30

#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC1_REG_STAMIN    0
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC1_REG_STAMAX    65535
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC1_REG_STADEF    30

#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC1_REG_APMIN    0
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC1_REG_APMAX    65535
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC1_REG_APDEF    30

#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC2_REG_STAMIN    0
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC2_REG_STAMAX    65535
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC2_REG_STADEF    30

#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC2_REG_APMIN    0
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC2_REG_APMAX    65535
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC2_REG_APDEF    30

#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC3_REG_STAMIN    0
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC3_REG_STAMAX    65535
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC3_REG_STADEF    30

#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC3_REG_APMIN    0
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC3_REG_APMAX    65535
#define WNI_CFG_RPE_AGING_THRESHOLD_FOR_AC3_REG_APDEF    30

#define WNI_CFG_NO_OF_ONCHIP_REORDER_SESSIONS_STAMIN    0
#define WNI_CFG_NO_OF_ONCHIP_REORDER_SESSIONS_STAMAX    2
#define WNI_CFG_NO_OF_ONCHIP_REORDER_SESSIONS_STADEF    1

#define WNI_CFG_NO_OF_ONCHIP_REORDER_SESSIONS_APMIN    0
#define WNI_CFG_NO_OF_ONCHIP_REORDER_SESSIONS_APMAX    2
#define WNI_CFG_NO_OF_ONCHIP_REORDER_SESSIONS_APDEF    1

#define WNI_CFG_SINGLE_TID_RC_STAMIN    0
#define WNI_CFG_SINGLE_TID_RC_STAMAX    1
#define WNI_CFG_SINGLE_TID_RC_STADEF    1

#define WNI_CFG_SINGLE_TID_RC_APMIN    0
#define WNI_CFG_SINGLE_TID_RC_APMAX    1
#define WNI_CFG_SINGLE_TID_RC_APDEF    1

#define WNI_CFG_RRM_ENABLED_STAMIN    0
#define WNI_CFG_RRM_ENABLED_STAMAX    1
#define WNI_CFG_RRM_ENABLED_STADEF    0

#define WNI_CFG_RRM_ENABLED_APMIN    0
#define WNI_CFG_RRM_ENABLED_APMAX    1
#define WNI_CFG_RRM_ENABLED_APDEF    0

#define WNI_CFG_RRM_OPERATING_CHAN_MAX_STAMIN    0
#define WNI_CFG_RRM_OPERATING_CHAN_MAX_STAMAX    8
#define WNI_CFG_RRM_OPERATING_CHAN_MAX_STADEF    0

#define WNI_CFG_RRM_OPERATING_CHAN_MAX_APMIN    0
#define WNI_CFG_RRM_OPERATING_CHAN_MAX_APMAX    8
#define WNI_CFG_RRM_OPERATING_CHAN_MAX_APDEF    0

#define WNI_CFG_RRM_NON_OPERATING_CHAN_MAX_STAMIN    0
#define WNI_CFG_RRM_NON_OPERATING_CHAN_MAX_STAMAX    8
#define WNI_CFG_RRM_NON_OPERATING_CHAN_MAX_STADEF    0

#define WNI_CFG_RRM_NON_OPERATING_CHAN_MAX_APMIN    0
#define WNI_CFG_RRM_NON_OPERATING_CHAN_MAX_APMAX    8
#define WNI_CFG_RRM_NON_OPERATING_CHAN_MAX_APDEF    0

#define WNI_CFG_TX_PWR_CTRL_ENABLE_STAMIN    0
#define WNI_CFG_TX_PWR_CTRL_ENABLE_STAMAX    1
#define WNI_CFG_TX_PWR_CTRL_ENABLE_STADEF    1

#define WNI_CFG_TX_PWR_CTRL_ENABLE_APMIN    0
#define WNI_CFG_TX_PWR_CTRL_ENABLE_APMAX    1
#define WNI_CFG_TX_PWR_CTRL_ENABLE_APDEF    1

#define WNI_CFG_MCAST_BCAST_FILTER_SETTING_STAMIN    0
#define WNI_CFG_MCAST_BCAST_FILTER_SETTING_STAMAX    3
#define WNI_CFG_MCAST_BCAST_FILTER_SETTING_STADEF    0

#define WNI_CFG_MCAST_BCAST_FILTER_SETTING_APMIN    0
#define WNI_CFG_MCAST_BCAST_FILTER_SETTING_APMAX    3
#define WNI_CFG_MCAST_BCAST_FILTER_SETTING_APDEF    0

#define WNI_CFG_BTC_DHCP_BT_SLOTS_TO_BLOCK_STAMIN    0
#define WNI_CFG_BTC_DHCP_BT_SLOTS_TO_BLOCK_STAMAX    255
#define WNI_CFG_BTC_DHCP_BT_SLOTS_TO_BLOCK_STADEF    0

#define WNI_CFG_BTC_DHCP_BT_SLOTS_TO_BLOCK_APMIN    0
#define WNI_CFG_BTC_DHCP_BT_SLOTS_TO_BLOCK_APMAX    255
#define WNI_CFG_BTC_DHCP_BT_SLOTS_TO_BLOCK_APDEF    0

#define WNI_CFG_DYNAMIC_PS_POLL_VALUE_STAMIN    0
#define WNI_CFG_DYNAMIC_PS_POLL_VALUE_STAMAX    255
#define WNI_CFG_DYNAMIC_PS_POLL_VALUE_STADEF    0

#define WNI_CFG_DYNAMIC_PS_POLL_VALUE_APMIN    0
#define WNI_CFG_DYNAMIC_PS_POLL_VALUE_APMAX    255
#define WNI_CFG_DYNAMIC_PS_POLL_VALUE_APDEF    0

#define WNI_CFG_PS_NULLDATA_AP_RESP_TIMEOUT_STAMIN    0
#define WNI_CFG_PS_NULLDATA_AP_RESP_TIMEOUT_STAMAX    80
#define WNI_CFG_PS_NULLDATA_AP_RESP_TIMEOUT_STADEF    0

#define WNI_CFG_TELE_BCN_WAKEUP_EN_STAMIN    0
#define WNI_CFG_TELE_BCN_WAKEUP_EN_STAMAX    1
#define WNI_CFG_TELE_BCN_WAKEUP_EN_STADEF    0

#define WNI_CFG_TELE_BCN_WAKEUP_EN_APMIN    0
#define WNI_CFG_TELE_BCN_WAKEUP_EN_APMAX    1
#define WNI_CFG_TELE_BCN_WAKEUP_EN_APDEF    0

#define WNI_CFG_TELE_BCN_TRANS_LI_STAMIN    0
#define WNI_CFG_TELE_BCN_TRANS_LI_STAMAX    7
#define WNI_CFG_TELE_BCN_TRANS_LI_STADEF    3

#define WNI_CFG_TELE_BCN_TRANS_LI_APMIN    0
#define WNI_CFG_TELE_BCN_TRANS_LI_APMAX    7
#define WNI_CFG_TELE_BCN_TRANS_LI_APDEF    3

#define WNI_CFG_TELE_BCN_TRANS_LI_IDLE_BCNS_STAMIN    5
#define WNI_CFG_TELE_BCN_TRANS_LI_IDLE_BCNS_STAMAX    255
#define WNI_CFG_TELE_BCN_TRANS_LI_IDLE_BCNS_STADEF    10

#define WNI_CFG_TELE_BCN_TRANS_LI_IDLE_BCNS_APMIN    5
#define WNI_CFG_TELE_BCN_TRANS_LI_IDLE_BCNS_APMAX    255
#define WNI_CFG_TELE_BCN_TRANS_LI_IDLE_BCNS_APDEF    10

#define WNI_CFG_TELE_BCN_MAX_LI_STAMIN    0
#define WNI_CFG_TELE_BCN_MAX_LI_STAMAX    7
#define WNI_CFG_TELE_BCN_MAX_LI_STADEF    5

#define WNI_CFG_TELE_BCN_MAX_LI_APMIN    0
#define WNI_CFG_TELE_BCN_MAX_LI_APMAX    7
#define WNI_CFG_TELE_BCN_MAX_LI_APDEF    5

#define WNI_CFG_TELE_BCN_MAX_LI_IDLE_BCNS_STAMIN    5
#define WNI_CFG_TELE_BCN_MAX_LI_IDLE_BCNS_STAMAX    255
#define WNI_CFG_TELE_BCN_MAX_LI_IDLE_BCNS_STADEF    15

#define WNI_CFG_TELE_BCN_MAX_LI_IDLE_BCNS_APMIN    5
#define WNI_CFG_TELE_BCN_MAX_LI_IDLE_BCNS_APMAX    255
#define WNI_CFG_TELE_BCN_MAX_LI_IDLE_BCNS_APDEF    15

#define WNI_CFG_BTC_A2DP_DHCP_BT_SUB_INTERVALS_STAMIN    0
#define WNI_CFG_BTC_A2DP_DHCP_BT_SUB_INTERVALS_STAMAX    255
#define WNI_CFG_BTC_A2DP_DHCP_BT_SUB_INTERVALS_STADEF    7

#define WNI_CFG_BTC_A2DP_DHCP_BT_SUB_INTERVALS_APMIN    0
#define WNI_CFG_BTC_A2DP_DHCP_BT_SUB_INTERVALS_APMAX    255
#define WNI_CFG_BTC_A2DP_DHCP_BT_SUB_INTERVALS_APDEF    7

#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMIN    0
#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STAMAX    65535
#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_STADEF    0

#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_APMIN    0
#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_APMAX    65535
#define WNI_CFG_INFRA_STA_KEEP_ALIVE_PERIOD_APDEF    0

#define WNI_CFG_ASSOC_STA_LIMIT_STAMIN    1
#define WNI_CFG_ASSOC_STA_LIMIT_STAMAX    32
#define WNI_CFG_ASSOC_STA_LIMIT_STADEF    10

#define WNI_CFG_ASSOC_STA_LIMIT_APMIN    1
#define WNI_CFG_ASSOC_STA_LIMIT_APMAX    32
#define WNI_CFG_ASSOC_STA_LIMIT_APDEF    10

#define WNI_CFG_SAP_CHANNEL_SELECT_START_CHANNEL_STAMIN    1
#define WNI_CFG_SAP_CHANNEL_SELECT_START_CHANNEL_STAMAX    252
#define WNI_CFG_SAP_CHANNEL_SELECT_START_CHANNEL_STADEF    1

#define WNI_CFG_SAP_CHANNEL_SELECT_START_CHANNEL_APMIN    1
#define WNI_CFG_SAP_CHANNEL_SELECT_START_CHANNEL_APMAX    252
#define WNI_CFG_SAP_CHANNEL_SELECT_START_CHANNEL_APDEF    1

#define WNI_CFG_SAP_CHANNEL_SELECT_END_CHANNEL_STAMIN    1
#define WNI_CFG_SAP_CHANNEL_SELECT_END_CHANNEL_STAMAX    252
#define WNI_CFG_SAP_CHANNEL_SELECT_END_CHANNEL_STADEF    11

#define WNI_CFG_SAP_CHANNEL_SELECT_END_CHANNEL_APMIN    1
#define WNI_CFG_SAP_CHANNEL_SELECT_END_CHANNEL_APMAX    252
#define WNI_CFG_SAP_CHANNEL_SELECT_END_CHANNEL_APDEF    11

#define WNI_CFG_SAP_CHANNEL_SELECT_OPERATING_BAND_STAMIN    0
#define WNI_CFG_SAP_CHANNEL_SELECT_OPERATING_BAND_STAMAX    4
#define WNI_CFG_SAP_CHANNEL_SELECT_OPERATING_BAND_STADEF    0

#define WNI_CFG_SAP_CHANNEL_SELECT_OPERATING_BAND_APMIN    0
#define WNI_CFG_SAP_CHANNEL_SELECT_OPERATING_BAND_APMAX    4
#define WNI_CFG_SAP_CHANNEL_SELECT_OPERATING_BAND_APDEF    0

#define WNI_CFG_AP_DATA_AVAIL_POLL_PERIOD_STAMIN    0
#define WNI_CFG_AP_DATA_AVAIL_POLL_PERIOD_STAMAX    65535
#define WNI_CFG_AP_DATA_AVAIL_POLL_PERIOD_STADEF    5

#define WNI_CFG_AP_DATA_AVAIL_POLL_PERIOD_APMIN    0
#define WNI_CFG_AP_DATA_AVAIL_POLL_PERIOD_APMAX    65535
#define WNI_CFG_AP_DATA_AVAIL_POLL_PERIOD_APDEF    5

#define WNI_CFG_ENABLE_CLOSE_LOOP_STAMIN    0
#define WNI_CFG_ENABLE_CLOSE_LOOP_STAMAX    1
#define WNI_CFG_ENABLE_CLOSE_LOOP_STADEF    0

#define WNI_CFG_ENABLE_CLOSE_LOOP_APMIN    0
#define WNI_CFG_ENABLE_CLOSE_LOOP_APMAX    1
#define WNI_CFG_ENABLE_CLOSE_LOOP_APDEF    0

#define WNI_CFG_ENABLE_LTE_COEX_STAMIN    0
#define WNI_CFG_ENABLE_LTE_COEX_STAMAX    1
#define WNI_CFG_ENABLE_LTE_COEX_STADEF    0

#define WNI_CFG_ENABLE_LTE_COEX_APMIN    0
#define WNI_CFG_ENABLE_LTE_COEX_APMAX    1
#define WNI_CFG_ENABLE_LTE_COEX_APDEF    0

#define WNI_CFG_AP_KEEP_ALIVE_TIMEOUT_STAMIN    1
#define WNI_CFG_AP_KEEP_ALIVE_TIMEOUT_STAMAX    255
#define WNI_CFG_AP_KEEP_ALIVE_TIMEOUT_STADEF    20

#define WNI_CFG_AP_KEEP_ALIVE_TIMEOUT_APMIN    1
#define WNI_CFG_AP_KEEP_ALIVE_TIMEOUT_APMAX    255
#define WNI_CFG_AP_KEEP_ALIVE_TIMEOUT_APDEF    20

#define WNI_CFG_GO_KEEP_ALIVE_TIMEOUT_STAMIN    1
#define WNI_CFG_GO_KEEP_ALIVE_TIMEOUT_STAMAX    255
#define WNI_CFG_GO_KEEP_ALIVE_TIMEOUT_STADEF    20

#define WNI_CFG_GO_KEEP_ALIVE_TIMEOUT_APMIN    1
#define WNI_CFG_GO_KEEP_ALIVE_TIMEOUT_APMAX    255
#define WNI_CFG_GO_KEEP_ALIVE_TIMEOUT_APDEF    20

#define WNI_CFG_ENABLE_MC_ADDR_LIST_STAMIN    0
#define WNI_CFG_ENABLE_MC_ADDR_LIST_STAMAX    1
#define WNI_CFG_ENABLE_MC_ADDR_LIST_STADEF    0

#define WNI_CFG_ENABLE_MC_ADDR_LIST_APMIN    0
#define WNI_CFG_ENABLE_MC_ADDR_LIST_APMAX    1
#define WNI_CFG_ENABLE_MC_ADDR_LIST_APDEF    0

#define WNI_CFG_ENABLE_UC_FILTER_STAMIN    0
#define WNI_CFG_ENABLE_UC_FILTER_STAMAX    1
#define WNI_CFG_ENABLE_UC_FILTER_STADEF    0

#define WNI_CFG_ENABLE_UC_FILTER_APMIN    0
#define WNI_CFG_ENABLE_UC_FILTER_APMAX    1
#define WNI_CFG_ENABLE_UC_FILTER_APDEF    0

#define WNI_CFG_ENABLE_LPWR_IMG_TRANSITION_STAMIN    0
#define WNI_CFG_ENABLE_LPWR_IMG_TRANSITION_STAMAX    1
#define WNI_CFG_ENABLE_LPWR_IMG_TRANSITION_STADEF    0

#define WNI_CFG_ENABLE_LPWR_IMG_TRANSITION_APMIN    0
#define WNI_CFG_ENABLE_LPWR_IMG_TRANSITION_APMAX    1
#define WNI_CFG_ENABLE_LPWR_IMG_TRANSITION_APDEF    0

#define WNI_CFG_ENABLE_MCC_ADAPTIVE_SCHED_STAMIN    0
#define WNI_CFG_ENABLE_MCC_ADAPTIVE_SCHED_STAMAX    1
#define WNI_CFG_ENABLE_MCC_ADAPTIVE_SCHED_STADEF    0

#define WNI_CFG_ENABLE_MCC_ADAPTIVE_SCHED_APMIN    0
#define WNI_CFG_ENABLE_MCC_ADAPTIVE_SCHED_APMAX    1
#define WNI_CFG_ENABLE_MCC_ADAPTIVE_SCHED_APDEF    0

#define WNI_CFG_DISABLE_LDPC_WITH_TXBF_AP_STAMIN    0
#define WNI_CFG_DISABLE_LDPC_WITH_TXBF_AP_STAMAX    1
#define WNI_CFG_DISABLE_LDPC_WITH_TXBF_AP_STADEF    0

#define WNI_CFG_DISABLE_LDPC_WITH_TXBF_AP_APMIN    0
#define WNI_CFG_DISABLE_LDPC_WITH_TXBF_AP_APMAX    1
#define WNI_CFG_DISABLE_LDPC_WITH_TXBF_AP_APDEF    0

#define WNI_CFG_AP_LINK_MONITOR_TIMEOUT_STAMIN    1
#define WNI_CFG_AP_LINK_MONITOR_TIMEOUT_STAMAX    255
#define WNI_CFG_AP_LINK_MONITOR_TIMEOUT_STADEF    3

#define WNI_CFG_AP_LINK_MONITOR_TIMEOUT_APMIN    1
#define WNI_CFG_AP_LINK_MONITOR_TIMEOUT_APMAX    255
#define WNI_CFG_AP_LINK_MONITOR_TIMEOUT_APDEF    3

#define CFG_PARAM_MAX_NUM         298
#define CFG_AP_IBUF_MAX_SIZE      237
#define CFG_AP_SBUF_MAX_SIZE      3422
#define CFG_STA_IBUF_MAX_SIZE     232
#define CFG_STA_SBUF_MAX_SIZE     3388
#define CFG_SEM_MAX_NUM           19

#define CFG_STA_MAGIC_DWORD     0xbeefbeef

#define CFG_AP_MAGIC_DWORD      0xdeaddead


#endif
